@@ -21,7 +21,7 @@ using namespace std;
 
 #include <biblesync.hh>
 
-// sync is a proper superset of announce,
+// sync is a proper superset of announce & beacon,
 // both inbound as well as outbound.
 // in these 2 arrays of strings, sync-specific
 // fields are placed after announce fields.
@@ -125,7 +125,8 @@ BibleSync_mode BibleSync::setMode(BibleSync_mode m,
     if (result != "")
     {
 	if (nav_func != NULL)
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("network setup errors."), result);
 	Shutdown();
     }
@@ -198,9 +199,8 @@ string BibleSync::Setup()
 				   sizeof(interface_addr)) < 0)
 		    {
 			ok_so_far = false;
-			retval += (string)" IP_MULTICAST_IF ["
-			    + inet_ntoa(interface_addr)
-			    + "]";
+			retval += (string)" IP_MULTICAST_IF "
+			    + inet_ntoa(interface_addr);
 		    }
 		}
 		// client is now ready for sendto(2) calls.
@@ -366,21 +366,26 @@ int BibleSync::ReceiveInternal()
 
 	// validate message: fixed values.
 	if (bsp.magic != BSP_MAGIC)
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("bad magic"), dump);
 	else if (bsp.version != BSP_PROTOCOL)
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("bad protocol version"), dump);
 	else if ((bsp.msg_type != BSP_ANNOUNCE) &&
 		 (bsp.msg_type != BSP_SYNC) &&
 		 (bsp.msg_type != BSP_BEACON))
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("bad msg type"), dump);
 	else if (bsp.num_packets != 1)
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("bad packet count"), dump);
 	else if (bsp.index_packet != 0)
-	    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	    (*nav_func)('E', EMPTY,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			BSP + _("bad packet index"), dump);
 
 	// basic header sanity tests passed.  now parse body content.
@@ -423,7 +428,8 @@ int BibleSync::ReceiveInternal()
 
 	    if (!ok_so_far)
 	    {
-		(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+		(*nav_func)('E', EMPTY,
+			    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			    BSP + _("bad body format"), dump);
 	    }
 	    else
@@ -441,7 +447,8 @@ int BibleSync::ReceiveInternal()
 			string info = BSP + _("missing required header ")
 			    + inbound_required[i]
 			    + ".";
-			(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+			(*nav_func)('E', EMPTY,
+				    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 				    info, dump);
 			// don't break -- find all missing.
 		    }
@@ -452,7 +459,7 @@ int BibleSync::ReceiveInternal()
 		    // find listening status for this guy.
 		    string pkt_uuid = content.find(BSP_APP_INSTANCE_UUID)->second;
 		    BibleSyncSpeakerMapIterator object = speakers.find(pkt_uuid);
-		    string source_addr = (string)"[" + inet_ntoa(source.sin_addr) + "]";
+		    string source_addr = inet_ntoa(source.sin_addr);
 		    bool listening;
 
 		    // spoof & listen check:
@@ -462,8 +469,12 @@ int BibleSync::ReceiveInternal()
 			if (object->second.addr != source_addr)	// spoof?
 			{
 			    // spock: "forbid...forbid!"
-			    (*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
-					BSP + _("UUID spoofed: wrong ipaddr."),
+			    (*nav_func)('E', pkt_uuid,
+					EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+					BSP + _("Spoof stopped: ") + pkt_uuid
+						+ " from " + source_addr
+						+ " instead of "
+						+ object->second.addr,
 					dump);
 			    continue;
 			}
@@ -489,7 +500,8 @@ int BibleSync::ReceiveInternal()
 		    if (i == sizeof(uuid_t))
 		    {
 #if 0
-			(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+			(*nav_func)('E', pkt_uuid,
+				    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 				    BSP + _("Ignoring echo."), dump);
 #endif
 			continue;
@@ -580,8 +592,6 @@ int BibleSync::ReceiveInternal()
 			    + " " + version;
 			domain = content.find(BSP_APP_DEVICE)->second;
 
-			alt = pkt_uuid;
-
 			info = (string)"beacon: "
 			    + content.find(BSP_APP_USER)->second
 			    + " @ " + source_addr;
@@ -603,6 +613,11 @@ int BibleSync::ReceiveInternal()
 
 			    new_speakers_size = speakers.size();
 
+			    // record address for first-time-seen beacon,
+			    // for anti-spoof checks in the future.
+			    if (cmd == 'S')
+				speakers[pkt_uuid].addr = source_addr;
+
 			    if (mode == BSP_MODE_SPEAKER)
 			    {
 				// speaker listens to no one.
@@ -610,18 +625,10 @@ int BibleSync::ReceiveInternal()
 			    }
 			    else
 			    {
-				// new speaker?
-				// record address for first-time-seen beacon,
-				// for anti-spoof checks in the future.
 				// listen to 1st speaker, ignore everyone else.
 				// the app can make other choices.
-
-				if (old_speakers_size != new_speakers_size)
+				if (cmd == 'S')
 				{
-				    // it's a new speaker.  save address.
-				    speakers[pkt_uuid].addr = source_addr;
-
-				    // iff he's the 1st speaker, listen to him.
 				    speakers[pkt_uuid].listen =
 					((old_speakers_size == 0) &&
 					 (new_speakers_size == 1));
@@ -639,7 +646,7 @@ int BibleSync::ReceiveInternal()
 		    if (cmd != 'x')
 		    {
 			receiving = true;			// re-xmit lock.
-			(*nav_func)(cmd,
+			(*nav_func)(cmd, pkt_uuid,
 				    bible, ref, alt, group, domain,
 				    info, dump);
 			receiving = false;			// re-xmit unlock.
@@ -688,7 +695,8 @@ int BibleSync::InitSelectRead(char *dump,
     FD_SET(server_fd, &read_set);
     if (select(server_fd+1, &read_set, NULL, NULL, &tv) < 0)
     {
-	(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	(*nav_func)('E', EMPTY,
+		    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 		    BSP + _("select < 0"), dump);
 	return -1;
     }
@@ -698,7 +706,8 @@ int BibleSync::InitSelectRead(char *dump,
 			       0, (sockaddr *)source,
 			       &source_length)) < 0))
     {
-	(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	(*nav_func)('E', EMPTY,
+		    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 		    BSP + _("recvfrom < 0"), dump);
 	return -1;
     }
@@ -787,7 +796,8 @@ BibleSync_xmit_status BibleSync::Transmit(char message_type,
     else
     {
 	retval = BSP_XMIT_FAILED;
-	(*nav_func)('E', EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+	(*nav_func)('E', EMPTY,
+		    EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 		    BSP + _("Transmit failed.\n"),
 		    _("Unable to multicast; BibleSync is now disabled. "
 		      "If your network connection changed while this program "
@@ -816,7 +826,7 @@ bool BibleSync::setPrivate(bool privacy)
 
 //
 // user decision to listen or not to a certain speaker.
-// speakerkey is the UUID as given during (*nav_func)('S', ...).
+// speakerkey is the UUID given during (*nav_func)('S', ...).
 //
 void BibleSync::listenToSpeaker(bool listen, string speakerkey)
 {
@@ -842,7 +852,8 @@ void BibleSync::ageSpeakers()
 	BibleSyncSpeakerMapIterator victim = object++;	// loop increment
 	if (--(victim->second.countdown) == 0)
 	{
-	    (*nav_func)('D', EMPTY, EMPTY, victim->first, EMPTY, EMPTY,
+	    (*nav_func)('D', victim->first,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			EMPTY, EMPTY);
 	    speakers.erase(victim);
 	}
@@ -862,7 +873,8 @@ void BibleSync::clearSpeakers()
 	     object != speakers.end();
 	     ++object)
 	{
-	    (*nav_func)('D', EMPTY, EMPTY, object->first, EMPTY, EMPTY,
+	    (*nav_func)('D', object->first,
+			EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
 			EMPTY, EMPTY);
 	}
     }
