@@ -613,7 +613,7 @@ action_save_cb (GtkAction *action,
 		_save_book (e);
 		break;
 	default:
-		GS_message (("\naction_save_cb oops!\n"));
+		XI_message (("\naction_save_cb oops!\n"));
 		break;
 	}
 }
@@ -1023,7 +1023,7 @@ _save_note(EDITOR * e)
 			"text/html",
 			(GtkHTMLSaveReceiverFn) _save_receiver,
 			string);
-	GS_message(("\n_save_note: %s\n",string->str));
+	XI_message(("\n_save_note: %s\n",string->str));
 	main_save_note (e->module, e->key, string->str);
 
 	g_string_free(string,TRUE);
@@ -1066,7 +1066,7 @@ _save_file (EDITOR * e)
 	filename = gtkhtml_editor_get_filename (GTKHTML_EDITOR(e->window));
 	as_html = gtkhtml_editor_get_html_mode (GTKHTML_EDITOR(e->window));
 
-	GS_message (("\n_save_file filename: %s\n",filename));
+	XI_message (("\n_save_file filename: %s\n",filename));
 
 	gtkhtml_editor_save (GTKHTML_EDITOR(e->window), filename, as_html, &error);
 	handle_error (&error);
@@ -1084,7 +1084,7 @@ _load_file (EDITOR * e, const gchar * filename)
 		g_free(e->filename);
 	e->filename = g_strdup(filename);
 
-	GS_message(("_load_file filename: %s",filename));
+	XI_message(("_load_file filename: %s",filename));
 
 	xml_set_value("Xiphos", "studypad", "lastfile",
 		      e->filename);
@@ -1136,7 +1136,7 @@ void editor_load_book(EDITOR * e)
 
 
 	title = g_strdup_printf("%s", e->module);
-	GS_message (("book: %s\noffset :%s", e->module, e->key));
+	XI_message (("book: %s\noffset :%s", e->module, e->key));
 
 	if (atol(e->key) != 0)
 		text = main_get_book_raw_text (e->module, e->key);
@@ -1428,7 +1428,7 @@ gint _create_new(const gchar * filename, const gchar * key, gint editor_type)
 		editor_new(_("Prayer List/Journal Editor"), editor);
 
 		GtkWidget *box;
-		UI_VBOX(box, FALSE, 0);
+		UI_VBOX(box, TRUE, 0);
 		gtk_widget_show (box);
 		GtkWidget *hpaned1 = UI_HPANE();
 		gtk_widget_show (hpaned1);
@@ -1546,7 +1546,7 @@ gint editor_create_new(const gchar * filename, const gchar * key, gint editor_ty
 		}
 		tmp = g_list_next(tmp);
 	}
-    	GS_message (("filename %s, key %s", (filename ? filename : "-null-"), (key ? key : "-null-")));
+    	XI_message (("filename %s, key %s", (filename ? filename : "-null-"), (key ? key : "-null-")));
 	return _create_new(filename, key, editor_type);
 }
 
