@@ -70,7 +70,7 @@ static void
 on_copy_activate(GtkMenuItem * menuitem,
 		 gpointer data)
 {
-	GS_message(("on_copy_activate"));
+	XI_message(("on_copy_activate"));
 	XIPHOS_HTML_COPY_SELECTION(text_html);
 }
 
@@ -213,7 +213,7 @@ gui_create_about_modules(void)
 
 	button = 
 #ifdef HAVE_GTK_310
-		gtk_button_new_from_icon_name ("gtk-close",
+		gtk_button_new_from_icon_name ("window-close",
                                GTK_ICON_SIZE_BUTTON);
 #else                        
 		gtk_button_new_from_stock (GTK_STOCK_CLOSE);
