@@ -168,7 +168,7 @@ gui_create_about_trans(void)
 				  GTK_BUTTONBOX_END);
 	button = 
 #ifdef HAVE_GTK_310
-		gtk_button_new_from_icon_name ("gtk-close",
+		gtk_button_new_from_icon_name ("window-close",
                                GTK_ICON_SIZE_BUTTON);
 #else                        
 		gtk_button_new_from_stock (GTK_STOCK_CLOSE);
