@@ -104,7 +104,7 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 		g_string_printf(name, _("Search result: %s"), settings.searchText);
 		while (verses) {
 			list_item = (RESULTS *) verses->data;
-			if (main_is_Bible_key(list_item->key)) {
+			if (main_is_Bible_key(list_item->module, list_item->key)) {
 				if (first_entry) {
 					module_name = g_strdup(list_item->module);
 					first_entry = FALSE;
@@ -162,7 +162,7 @@ void gui_verselist_to_bookmarks(GList * verses, gint save_as_single)
 			tmpbuf = list_item->key;
 			g_string_printf(str, "%s, %s", tmpbuf,
 					 module_name);
-			GS_message(("bookmark: %s",str->str));
+			XI_message(("bookmark: %s",str->str));
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &iter, &parent);
 			gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
@@ -758,6 +758,12 @@ static gboolean button_release_event(GtkWidget * widget,
 		gtk_widget_set_sensitive(menu.delete, TRUE);
 		is_selected = TRUE;
 	}
+
+	if (!module || !strcmp(module, "")) {
+		g_free(module);
+		module = g_strdup(settings.MainWindowModule);
+	}
+
 	switch (event->button) {
 	case 1:
 		button_one = TRUE;
