@@ -94,7 +94,7 @@ void gui_get_clipboard_text_for_lookup (GtkClipboard *clipboard,
 	int len = 0;
 
 	if (text == NULL) return;
-	GS_message(("src/gnome2/dictlex.c: text =>%s<",text));
+	XI_message(("src/gnome2/dictlex.c: text =>%s<",text));
 
 	key = g_strdelimit((char*)text, "&.,\"<>;:?", ' ');
 	key = g_strstrip((char*)key);
@@ -211,7 +211,7 @@ void dict_key_entry_changed(GtkEntry * entry, gpointer data)
 	gchar *buf = NULL;
 
 	buf = (gchar*)gtk_entry_get_text(entry);
-	GS_message(("dict_key_entry_changed: %s",buf));
+	XI_message(("dict_key_entry_changed: %s",buf));
 	if (strlen(buf) < 2 )
 		return;
 
@@ -381,10 +381,18 @@ GtkWidget *gui_create_dictionary_pane(void)
 
 
   	dict_drop_down = gtk_toggle_button_new ();
- 	 gtk_widget_show (dict_drop_down);
+	gtk_widget_show (dict_drop_down);
 	gtk_box_pack_start(GTK_BOX(hbox2), dict_drop_down, FALSE, TRUE, 0);
 
-  	arrow1 = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+#ifdef HAVE_GTK_310
+	{
+		gchar *arrow_path = image_locator("arrow_down_box.png");
+		arrow1 = gtk_image_new_from_file(arrow_path);
+		g_free(arrow_path);
+	}
+#else
+	arrow1 = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+#endif
   	gtk_widget_show (arrow1);
   	gtk_container_add (GTK_CONTAINER (dict_drop_down), arrow1);
 
@@ -395,8 +403,8 @@ GtkWidget *gui_create_dictionary_pane(void)
 
 	image1 = 
 #ifdef HAVE_GTK_310
-	    gtk_image_new_from_icon_name ("go-up",
-                    		    GTK_ICON_SIZE_BUTTON);
+	    gtk_image_new_from_icon_name("go-up",
+					 GTK_ICON_SIZE_BUTTON);
 #else                        
 		
 	    gtk_image_new_from_stock(GTK_STOCK_GO_UP,
@@ -413,7 +421,7 @@ GtkWidget *gui_create_dictionary_pane(void)
 	image2 = 
 #ifdef HAVE_GTK_310
 	    gtk_image_new_from_icon_name ("go-down",
-                    		    GTK_ICON_SIZE_BUTTON);
+					  GTK_ICON_SIZE_BUTTON);
 #else                        
 		
 	    gtk_image_new_from_stock(GTK_STOCK_GO_DOWN,
