@@ -73,7 +73,7 @@ gboolean dialog_vbox1_key_press_event_cb (GtkWidget   * widget,
 
 static gchar *get_module(const gchar * key)
 {
-	if (main_is_Bible_key((gchar*)key))
+	if (main_is_Bible_key(settings.MainWindowModule, (gchar*)key))
 		return g_strdup(settings.MainWindowModule);
 	return NULL;
 
@@ -293,7 +293,7 @@ static gboolean _save_verselist_2_html(BK_EXPORT *data)
 
 	/* not sure how well this will work with windows */
 	if (!g_file_set_contents (filename, str->str, str->len, NULL))
-		GS_warning(("Unable to save %s", filename));
+		XI_warning(("Unable to save %s", filename));
 
 	g_string_free(str,1);
 	return 1;
@@ -521,7 +521,7 @@ static void _save_iter(GtkTreeIter * iter, BK_EXPORT *data)
 
 	/* not sure how well this will work with windows */
 	if (!g_file_set_contents (filename, str->str, str->len, NULL))
-		GS_warning(("Unable to save %s", filename));
+		XI_warning(("Unable to save %s", filename));
 
 	g_string_free(str,1);
 }
