@@ -148,7 +148,7 @@ void _get_export_filename(void)
 #ifndef USE_GTKBUILDER
 	glade_file = gui_general_user_file("export-dialog" UI_SUFFIX, FALSE);
 	g_return_if_fail(glade_file != NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 #endif
 
 	/* build the widget */
@@ -314,7 +314,7 @@ gint _check_for_distribution_license(gchar * mod_name)
 						mod_name,
 				 		"DistributionLicense");
 	g_free(conf_file);
-	GS_message(("DistributionLicense: %s",distributionlicense));
+	XI_message(("DistributionLicense: %s",distributionlicense));
 
 	if (!distributionlicense || (distributionlicense &&
 				          g_strstr_len(distributionlicense,
@@ -480,7 +480,7 @@ void gui_export_dialog(void)
 
 	gchar *glade_file = gui_general_user_file("export-dialog" UI_SUFFIX, FALSE);
 	g_return_if_fail(glade_file != NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 
 	dist_license = _check_for_distribution_license(settings.MainWindowModule);
 
@@ -531,18 +531,18 @@ void gui_export_dialog(void)
 	g_signal_connect(dialog, "response",
 			 G_CALLBACK(on_dialog_export_passage_response), NULL);
 
-	max = main_get_max_verses ();
-	gtk_spin_button_set_range (GTK_SPIN_BUTTON (d.sb_start_verse),
-				   1, max);
-	gtk_spin_button_set_range (GTK_SPIN_BUTTON (d.sb_end_verse),
-				   1, max);
-	curVerse = main_get_current_verse();
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (d.sb_start_verse),
-				   curVerse);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (d.sb_end_verse),
-				   curVerse);
-	gtk_widget_set_sensitive (d.sb_start_verse, FALSE);
-	gtk_widget_set_sensitive (d.sb_end_verse, FALSE);
+	max = main_get_max_verses(settings.MainWindowModule);
+	gtk_spin_button_set_range(GTK_SPIN_BUTTON (d.sb_start_verse),
+				  1, max);
+	gtk_spin_button_set_range(GTK_SPIN_BUTTON (d.sb_end_verse),
+				  1, max);
+	curVerse = main_get_current_verse(settings.MainWindowModule);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON (d.sb_start_verse),
+				  curVerse);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON (d.sb_end_verse),
+				  curVerse);
+	gtk_widget_set_sensitive(d.sb_start_verse, FALSE);
+	gtk_widget_set_sensitive(d.sb_end_verse, FALSE);
 
 	/* experiment: hide single verse option; subsumed into multi-verse. */
 	gtk_widget_hide(d.rb_verse);
