@@ -69,7 +69,7 @@ static void dialog_destroy(GObject * object, gpointer data)
 {
 	g_free(dialog);
 	dialog = NULL;
-	GS_print(("\nall done\n"));
+	XI_print(("\nall done\n"));
 }
 
 
@@ -167,7 +167,9 @@ static void create_find_dialog(GtkWidget * htmlwidget)
 	GtkWidget *hbox66;
 	GtkWidget *dialog_action_area29;
 	GtkWidget *hbuttonbox8;
+#ifndef HAVE_GTK_310
 	GtkWidget *alignment;
+#endif
 	GtkWidget *hbox5;
 	GtkWidget *image;
 	GtkWidget *label12;
@@ -243,7 +245,7 @@ static void create_find_dialog(GtkWidget * htmlwidget)
 
 	dialog->find = 
 #ifdef HAVE_GTK_310
-		gtk_button_new_from_icon_name ("gtk-find",
+		gtk_button_new_from_icon_name ("edit-find",
                               GTK_ICON_SIZE_BUTTON);
 #else                      
 		gtk_button_new_from_stock(GTK_STOCK_FIND);	//gtk_button_new_with_label(_("Find"));
@@ -256,17 +258,21 @@ static void create_find_dialog(GtkWidget * htmlwidget)
 	gtk_container_add(GTK_CONTAINER(hbuttonbox8), dialog->next);
 	//GTK_WIDGET_SET_FLAGS(dialog->next, GTK_CAN_DEFAULT);
 
+#ifndef HAVE_GTK_310
 	alignment = gtk_alignment_new(0.5, 0.5, 0, 0);
 	gtk_widget_show(alignment);
 	gtk_container_add(GTK_CONTAINER(dialog->next), alignment);
 
+#endif
 	UI_HBOX(hbox5, FALSE, 2);
 	gtk_widget_show(hbox5);
+#ifndef HAVE_GTK_310
 	gtk_container_add(GTK_CONTAINER(alignment), hbox5);
+#endif
 
 	image =
 #ifdef HAVE_GTK_310
-	    gtk_image_new_from_icon_name ("gtk-find",
+	    gtk_image_new_from_icon_name ("edit-find",
                                GTK_ICON_SIZE_BUTTON);
 #else                 
 	    gtk_image_new_from_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_BUTTON);
@@ -281,7 +287,7 @@ static void create_find_dialog(GtkWidget * htmlwidget)
 
 	dialog->close = 
 #ifdef HAVE_GTK_310
-		gtk_button_new_from_icon_name ("gtk-close",
+		gtk_button_new_from_icon_name ("window-close",
                               GTK_ICON_SIZE_BUTTON );
 #else 
 		gtk_button_new_from_stock(GTK_STOCK_CLOSE);	//gtk_button_new_with_label(_("Close")); 
