@@ -110,7 +110,7 @@ on_help_contents_activate(GtkMenuItem * menuitem, gpointer user_data)
 #else
 	gtk_show_uri (NULL, "ghelp:xiphos", gtk_get_current_event_time(), &error);
 	if (error != NULL) {
-		GS_warning(("%s", error->message));
+		XI_warning(("%s", error->message));
 		g_error_free(error);
 	}
 
@@ -509,6 +509,9 @@ on_side_preview_activate(GtkCheckMenuItem * menuitem, gpointer user_data)
 G_MODULE_EXPORT void
 on_quit_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
+	/* discover main window internal geometry before we go. */
+	final_pane_sizes();
+
 #if defined(WIN32) && defined(HAVE_DBUS)
 	/* we started dbus-daemon ourselves, so we must kill it, too. */
 	extern GPid dbus_pid;
@@ -648,14 +651,18 @@ redisplay_to_realign()
 				     settings.currentverse);
 	main_url_handler(url, TRUE);
 	g_free(url);
-	if (settings.DictWindowModule) {
+	if (settings.DictWindowModule
+	    && *settings.DictWindowModule	/* not empty */
+	    && settings.dictkey) {
 		url = g_strdup_printf("sword://%s/%s",
 				      settings.DictWindowModule,
 				      settings.dictkey);
 		main_url_handler(url, TRUE);
 		g_free(url);
 	}
-	if (settings.book_mod) {
+	if (settings.book_mod
+	    && *settings.book_mod		/* not empty */
+	    && settings.book_key) {
 		url = g_strdup_printf("sword://%s/%s",
 				      settings.book_mod,
 				      settings.book_key);
