@@ -365,7 +365,7 @@ static gboolean  delete_event (GtkWidget *widget,
  *    get and store pane sizes
  *
  * Return value
- *   void
+ *   gboolean
  */
 
 static gboolean epaned_button_release_event(GtkWidget * widget,
@@ -408,6 +408,32 @@ static gboolean epaned_button_release_event(GtkWidget * widget,
 }
 
 
+/******************************************************************************
+ * Name
+ *   final_pane_sizes
+ *
+ * Synopsis
+ *   #include "gui/main_window.h"
+ *
+ *   void final_pane_sizes()
+ *
+ * Description
+ *   on quit, make a last query for pane sizes.
+ *   this is needed because e.g. "maximize window" in the title bar does
+ *   not call on_epaned_button_release_event for each newly-modified pane.
+ *
+ * Return value
+ *   void
+ */
+
+void final_pane_sizes()
+{
+    epaned_button_release_event(GTK_WIDGET(widgets.epaned), NULL, (gchar *) "epaned");
+    epaned_button_release_event(GTK_WIDGET(widgets.vpaned), NULL, (gchar *) "vpaned");
+    epaned_button_release_event(GTK_WIDGET(widgets.vpaned2),NULL, (gchar *) "vpaned2");
+    epaned_button_release_event(GTK_WIDGET(widgets.hpaned), NULL, (gchar *) "hpaned1");
+}
+
 /******************************************************************************
  * Name
  *   on_configure_event
@@ -820,7 +846,7 @@ gboolean on_vbox1_key_press_event(GtkWidget * widget, GdkEventKey * event,
 			/* FIXME: needs the html widget as first pram */
 		break;
 	}
-	GS_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d",
+	XI_message(("on_vbox1_key_press_event\nkeycode: %d, keysym: %0x, state: %d",
 		    event->hardware_keycode, event->keyval, state));
 	return FALSE;
 }
@@ -875,8 +901,8 @@ void create_mainwindow(void)
 	*/
 	settings.shadow_type = GTK_SHADOW_IN;
 
-	GS_print(("%s xiphos-%s\n", "Starting", VERSION));
-	GS_print(("%s\n\n", "Building Xiphos interface"));
+	XI_print(("%s xiphos-%s\n", "Starting", VERSION));
+	XI_print(("%s\n\n", "Building Xiphos interface"));
 
 	widgets.studypad_dialog = NULL;
 
