@@ -214,7 +214,7 @@ void _global_option_main_pane(GtkMenuItem * menuitem, const gchar * option)
 {
 	gchar *key = _get_key(menu_mod_name);
 	gchar *mod = (gchar*) (is_dialog ? dialog->mod_name : menu_mod_name);
-	GS_message(("module option = %s",option));
+	XI_message(("module option = %s",option));
     	if (key) {
 		gchar *url = g_strdup_printf ("sword://%s/%s",
 					     mod,
@@ -260,7 +260,7 @@ static void on_edit_percomm_activate (GtkMenuItem * menuitem, gpointer user_data
     	else
     		key = _get_key(menu_mod_name);
     	if (key ) {
-		GS_message(("\n\npercomm key: %s\n\n",key));
+		XI_message(("\n\npercomm key: %s\n\n",key));
 		editor_create_new((gchar *)user_data, (gchar *) key, NOTE_EDITOR);
 		g_free (key);
 	 }
@@ -285,7 +285,7 @@ static void on_edit_percomm_activate (GtkMenuItem * menuitem, gpointer user_data
 
 static void on_edit_prayerlist_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-    	GS_message(("settings.book_key: %s",(char*)(is_dialog ?
+    	XI_message(("settings.book_key: %s",(char*)(is_dialog ?
 						  dialog->key :
 						  settings.book_key)));
 	editor_create_new((gchar *)user_data,
@@ -888,6 +888,50 @@ G_MODULE_EXPORT void on_xrefnotenumbers_activate (GtkCheckMenuItem * menuitem, g
 }
 
 
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/menu_popup.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+G_MODULE_EXPORT void on_xlit_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+	_global_option_main_pane((GtkMenuItem*)menuitem, "Transliterated Forms"); /* string not seen by user */
+}
+
+
+/******************************************************************************
+ * Name
+ *
+ *
+ * Synopsis
+ *   #include "gui/menu_popup.h"
+ *
+ *
+ *
+ * Description
+ *
+ *
+ * Return value
+ *
+ */
+
+G_MODULE_EXPORT void on_enumerated_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
+{
+	_global_option_main_pane((GtkMenuItem*)menuitem, "Enumerations"); /* string not seen by user */
+}
+
+
 /******************************************************************************
  * Name
  *
@@ -1553,6 +1597,20 @@ G_MODULE_EXPORT void _add_and_check_global_opts(GladeXML *gxml,
 		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), ops->variants_all);
 	}
 
+    	item = UI_GET_ITEM(gxml, "xlit");
+
+	if (main_check_for_global_option((gchar*) mod_name, "OSISXlit")) {
+		gtk_widget_show(item);
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->xlit);
+	}
+
+    	item = UI_GET_ITEM(gxml, "enumerated");
+
+	if (main_check_for_global_option((gchar*) mod_name, "OSISEnum")) {
+		gtk_widget_show(item);
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), ops->enumerated);
+	}
+
 	item = UI_GET_ITEM(gxml, "image_content");
 
 	if (ops->image_content != -1) {
@@ -1709,7 +1767,7 @@ GtkWidget * _create_popup_menu (XiphosHtml *html, const gchar * mod_name, DIALOG
 	GladeXML *gxml;
 #endif
     	const gchar *mname = (is_dialog ? d->mod_name : mod_name);
-	GS_message(("_create_popup_menu mod_name:%s",mod_name));
+	XI_message(("_create_popup_menu mod_name:%s",mod_name));
 	if (!mname || !*mname)
 		return NULL;
 
