@@ -130,7 +130,7 @@ static gboolean lookup_entry_press_callback(GtkWidget * widget,
 		break;
 	}
 	*/
-	GS_message(("lookup_entry_press_callback\nkeycode: %d",event->hardware_keycode));
+	XI_message(("lookup_entry_press_callback\nkeycode: %d",event->hardware_keycode));
 	return FALSE;
 
 
@@ -351,7 +351,15 @@ GtkWidget *gui_navbar_book_new(void)
 			   FALSE, 0);
 	//gtk_button_set_relief (GTK_BUTTON (navbar_book.button_list), GTK_RELIEF_NONE);
 
-	arrow1 = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+#ifdef HAVE_GTK_310
+	{
+		gchar *arrow_path = image_locator("arrow_down_box.png");
+		arrow1 = gtk_image_new_from_file(arrow_path);
+		g_free(arrow_path);
+	}
+#else
+  	arrow1 = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+#endif
 	gtk_widget_show(arrow1);
 	gtk_container_add(GTK_CONTAINER(navbar_book.button_list), arrow1);
 
