@@ -292,7 +292,15 @@ GtkWidget *gui_navbar_book_dialog_new(DIALOG_DATA * d)
 			   FALSE, 0);
 	//gtk_button_set_relief (GTK_BUTTON (d->navbar_book.button_list), GTK_RELIEF_NONE);
 
+#ifdef HAVE_GTK_310
+	{
+		gchar *arrow_path = image_locator("arrow_down_box.png");
+		arrow1 = gtk_image_new_from_file(arrow_path);
+		g_free(arrow_path);
+	}
+#else
 	arrow1 = gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_OUT);
+#endif
 	gtk_widget_show(arrow1);
 	gtk_container_add(GTK_CONTAINER(d->navbar_book.button_list), arrow1);
 
