@@ -199,13 +199,13 @@ static gboolean select_book_button_press_callback(GtkWidget * widget,
 #endif
 
 	g_get_current_time( &start_time );
-//	GS_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
+//	XI_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
 
 	menu = main_versekey_drop_down_book_menu(navbar_versekey, NB_MAIN,
 						NULL,NULL);
 
 	g_get_current_time( &end_time );
-//	GS_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
+//	XI_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
 #ifdef WIN32
 	time_diff = ((end_time.tv_sec - start_time.tv_sec) * 1000000) + (end_time.tv_usec - start_time.tv_usec);
 	time_add = 0;
@@ -400,7 +400,12 @@ static void on_entry_activate(GtkEntry * entry, gpointer user_data)
 		return;
 	}
 
-	gkey = main_get_valid_key((gchar*)buf);
+	gkey = main_get_valid_key(settings.MainWindowModule, (gchar*)buf);
+
+	// we got a valid key. but was it really a valid key within v11n?
+	// for future use in determining whether to show normal navbar content.
+	navbar_versekey.valid_key = main_is_Bible_key(settings.MainWindowModule, gkey);
+
 	if (settings.special_anchor)
 		*settings.special_anchor = '#';			/* put it back. */
 	if (gkey == NULL)
@@ -410,7 +415,8 @@ static void on_entry_activate(GtkEntry * entry, gpointer user_data)
 							     ? settings.special_anchor
 							     : ""));
 
-	navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,settings.MainWindowModule);
+	navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,
+						      settings.MainWindowModule);
 	main_navbar_versekey_set(navbar_versekey, gkey);
 	main_url_handler(url, TRUE);
 	if (url)
@@ -948,7 +954,7 @@ GtkWidget *gui_navbar_versekey_new(void)
 	
 	gchar *glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
 	g_return_val_if_fail((glade_file != NULL), NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 
 	/* build the widget */
 #ifdef USE_GTKBUILDER
