@@ -294,12 +294,12 @@ gboolean select_book_button_press_callback(GtkWidget * widget,
 	guint32 time_add;
 #endif
 	g_get_current_time( &start_time );
-//	GS_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
+//	XI_message(("Start time is: %d sec %d mil", start_time.tv_sec, start_time.tv_usec));
 
 	menu = main_versekey_drop_down_book_menu(dialog->navbar, NB_DIALOG, dialog, NULL);
 
 	g_get_current_time( &end_time );
-//	GS_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
+//	XI_message(("End time is: %d sec %d mil", end_time.tv_sec, end_time.tv_usec));
 #ifdef WIN32
 	time_diff = ((end_time.tv_sec - start_time.tv_sec) * 1000000) + (end_time.tv_usec - start_time.tv_usec);
 	time_add = 0;
@@ -437,7 +437,12 @@ static void on_entry_activate(GtkEntry * entry, DIALOG_DATA *dialog)
 	if ((settings.special_anchor = strchr(buf, '#')) ||	/* thml */
 	    (settings.special_anchor = strchr(buf, '!')))	/* osisref */
 		*settings.special_anchor = '\0';
-	const gchar *gkey = main_get_valid_key((gchar*)buf);
+	const gchar *gkey = main_get_valid_key(dialog->mod_name, (gchar*)buf);
+
+	// we got a valid key. but was it really a valid key within v11n?
+	// for future use in determining whether to show normal navbar content.
+	dialog->navbar.valid_key = main_is_Bible_key(dialog->mod_name, gkey);
+
 	if (settings.special_anchor)
 		*settings.special_anchor = '#';			/* put it back. */
 	if (gkey == NULL)
@@ -864,7 +869,7 @@ GtkWidget *gui_navbar_versekey_dialog_new(DIALOG_DATA * dialog)
 	
 	gchar *glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
 	g_return_val_if_fail((glade_file != NULL), NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 
 	/* build the widget */
 #ifdef USE_GTKBUILDER
