@@ -424,7 +424,12 @@ static void on_entry_activate(GtkEntry * entry, EDITOR * editor)
 	if ((settings.special_anchor = strchr(buf, '#')) ||	/* thml */
 	    (settings.special_anchor = strchr(buf, '!')))	/* osisref */
 		*settings.special_anchor = '\0';
-	const gchar *gkey = main_get_valid_key((gchar*)buf);
+	const gchar *gkey = main_get_valid_key(settings.MainWindowModule, (gchar*)buf);
+
+	// we got a valid key. but was it really a valid key within v11n?
+	// for future use in determining whether to show normal navbar content.
+	editor->navbar.valid_key = main_is_Bible_key(settings.MainWindowModule, gkey);
+
 	if (settings.special_anchor)
 		*settings.special_anchor = '#';			/* put it back. */
 	if (gkey == NULL)
@@ -433,7 +438,8 @@ static void on_entry_activate(GtkEntry * entry, EDITOR * editor)
 							     ? settings.special_anchor
 							     : ""));
 
-	editor->navbar.module_name = g_string_assign(editor->navbar.module_name,settings.MainWindowModule);
+	editor->navbar.module_name = g_string_assign(editor->navbar.module_name,
+						     settings.MainWindowModule);
 	main_navbar_versekey_set(editor->navbar, gkey);
 
 	editor_load_note(editor, NULL, gkey);
@@ -468,7 +474,7 @@ gboolean on_button_verse_menu_verse_scroll_event(GtkWidget * widget,
                                             GdkEvent * event,
                                             EDITOR * editor)
 {
-	GS_message(("%s","on_button_verse_menu_verse_scroll_event"));
+	XI_message(("%s","on_button_verse_menu_verse_scroll_event"));
 	main_navbar_versekey_spin_verse(editor->navbar,
 				event->scroll.direction);
 	return FALSE;
@@ -905,7 +911,7 @@ GtkWidget *gui_navbar_versekey_editor_new(EDITOR * editor)
 	
 	gchar *glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
 	g_return_val_if_fail((glade_file != NULL), NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 
 	/* build the widget */
 #ifdef USE_GTKBUILDER
