@@ -145,14 +145,14 @@ gboolean select_book_button_press_callback(GtkWidget * widget,
 #endif
     
 	g_get_current_time( &start_time );
-	GS_message(("Start time is: %ld sec %ld mil", start_time.tv_sec, start_time.tv_usec));
+	XI_message(("Start time is: %ld sec %ld mil", start_time.tv_sec, start_time.tv_usec));
 
 	menu = main_versekey_drop_down_book_menu(navbar_parallel,
 						NB_PARALLEL,
 						NULL, NULL);
 
 	g_get_current_time( &end_time );
-	GS_message(("End time is: %ld sec %ld mil", end_time.tv_sec, end_time.tv_usec));
+	XI_message(("End time is: %ld sec %ld mil", end_time.tv_sec, end_time.tv_usec));
 #ifdef WIN32
 	time_diff = ((end_time.tv_sec - start_time.tv_sec) * 1000000) + (end_time.tv_usec - start_time.tv_usec);
 	time_add = 0;
@@ -290,15 +290,29 @@ static void on_entry_activate(GtkEntry * entry, gpointer user_data)
 	const gchar *buf = gtk_entry_get_text(entry);
 	if (buf == NULL)
 		return;
+
 	/* handle potential subsection anchor */
 	if ((settings.special_anchor = strchr(buf, '#')) ||	/* thml */
 	    (settings.special_anchor = strchr(buf, '!')))	/* osisref */
 		*settings.special_anchor = '\0';
-	settings.cvparallel = (gchar*)main_get_valid_key((gchar*)buf);
+
+	/* gross.  we need a valid key.
+	 * but we have multiple modules whose v11n may not even be the same.
+	 * fall back 10 yards and punt: arbitrarily take the 1st one.
+	 * if there aren't any, use main window bible.
+	 */
+	settings.cvparallel = (gchar*)main_get_valid_key(
+	    (settings.parallel_list
+	     ? settings.parallel_list[0]
+	     : settings.MainWindowModule),
+	    (gchar*)buf);
+
 	if (settings.special_anchor)
 		*settings.special_anchor = '#';			/* put it back. */
 	if (settings.cvparallel == NULL)
 		return;
+
+	navbar_parallel.valid_key = TRUE;
 	main_navbar_versekey_set(navbar_parallel, settings.cvparallel);
 	main_update_parallel_page_detached();
 	if (sync_on) {
@@ -815,7 +829,7 @@ GtkWidget *gui_navbar_versekey_parallel_new(void)
 	
 	glade_file = gui_general_user_file("navbar_versekey" UI_SUFFIX, FALSE);
 	g_return_val_if_fail((glade_file != NULL), NULL);
-	GS_message(("%s",glade_file));
+	XI_message(("%s",glade_file));
 
 	/* build the widget */
 #ifdef USE_GTKBUILDER
@@ -827,6 +841,7 @@ GtkWidget *gui_navbar_versekey_parallel_new(void)
 	navbar_parallel.dialog = TRUE;
 	navbar_parallel.module_name = g_string_new(settings.MainWindowModule);
 	navbar_parallel.key =  g_string_new(settings.currentverse);
+	navbar_parallel.valid_key = TRUE;
 
 	navbar_parallel.navbar = UI_GET_ITEM(gxml, "navbar");
 	navbar_parallel.button_history_back = UI_GET_ITEM(gxml, "button_history_back");
