@@ -250,15 +250,15 @@ string_is_color(gchar * color)
 	gint i;
 
 	if (!color) {
-		GS_warning(("string_is_color, pointer NULL\n"));
+		XI_warning(("string_is_color, pointer NULL\n"));
 		return 0;
 	}
 	if (strlen(color) != 7) {
-		GS_warning(("string_is_color, strlen(%s) != 7\n", color));
+		XI_warning(("string_is_color, strlen(%s) != 7\n", color));
 		return 0;
 	}
 	if (color[0] != '#') {
-		GS_warning(("string_is_color, 0 in %s is not #\n", color));
+		XI_warning(("string_is_color, 0 in %s is not #\n", color));
 		return 0;
 	}
 	for (i = 1; i < 7; i++) {
@@ -266,13 +266,13 @@ string_is_color(gchar * color)
 		    || (color[i] < 48)
 		    || ((color[i] > 57) && (color[i] < 65))
 		    || ((color[i] > 70) && (color[i] < 97))) {
-			GS_warning
+			XI_warning
 			    (("string_is_color, %d in %s is not from a color, it is %d\n",
 			     i, color, color[i]));
 			return 0;
 		}
 	}
-	GS_print(("string_is_color, %s is color\n", color));
+	XI_print(("string_is_color, %s is color\n", color));
 	return 1;
 
 }
@@ -1891,9 +1891,10 @@ on_combobox16_changed(GtkComboBox * combobox,
 	if (clear)
 		*buf = '\0';
 
-	xml_set_value("Xiphos", "locale", "special", (clear ? NONE : buf));
+	/* NOTE: These 2 uses of "None" are NOT TRANSLATABLE. */
+	xml_set_value("Xiphos", "locale", "special", (clear ? "None" : buf));
 	g_free(settings.special_locale);	/* dispose of old content */
-	settings.special_locale = (clear ? g_strdup(NONE) : g_strdup(buf));
+	settings.special_locale = (clear ? g_strdup("None") : g_strdup(buf));
 }
 
 
@@ -2874,7 +2875,7 @@ void ps_button_add(GtkButton * button, gpointer user_data)
 #else
 	GladeXML *gxml;
 #endif
-	gchar *glade_file = gui_general_user_file("prefs" UI_SUFFIX, FALSE);
+	gchar *glade_file = gui_general_user_file("selector-prefs" UI_SUFFIX, FALSE);
 	g_return_if_fail(glade_file != NULL);
 
 #ifdef USE_GTKBUILDER
