@@ -66,6 +66,7 @@ void set_current_tab (PASSAGE_TAB_INFO *pt);
 
 gboolean stop_refresh = FALSE;
 gboolean change_tabs_no_redisplay = FALSE;
+gboolean closing_tab = FALSE;
 
 GList *passage_list;
 
@@ -206,7 +207,7 @@ void set_current_tab (PASSAGE_TAB_INFO *pt)
 	if (stop_refresh)
 		return;
 
-	if (ot != NULL && ot->button_close != NULL) {
+	if (!closing_tab && ot != NULL && ot->button_close != NULL) {
 		gtk_widget_set_sensitive(ot->button_close, FALSE);
 	}
 	cur_passage_tab = pt;
@@ -550,7 +551,7 @@ void gui_load_tabs(const gchar *filename)
 		} else {
 			tabs_dir = g_strdup_printf("%s/tabs/",settings.gSwordDir);
 			if (g_access(tabs_dir, F_OK) == -1) {
-				GS_message(("Creating new tabs directory\n"));
+				XI_message(("Creating new tabs directory\n"));
 				gui_save_tabs(filename);
 			}
 			file = g_strdup_printf("%s%s",tabs_dir,filename);
@@ -754,9 +755,11 @@ void gui_load_tabs(const gchar *filename)
 static void on_notebook_main_close_page(GtkButton * button, gpointer user_data)
 {
 	PASSAGE_TAB_INFO *pt = (PASSAGE_TAB_INFO*)user_data;
+	closing_tab = TRUE;
 	gui_close_passage_tab(gtk_notebook_page_num
 				(GTK_NOTEBOOK(widgets.notebook_main),
 				pt->page_widget));
+	closing_tab = FALSE;
 }
 
 
@@ -790,7 +793,7 @@ static GtkWidget* tab_widget_new(PASSAGE_TAB_INFO *tbinf, const gchar *label_tex
 
 	g_return_val_if_fail(label_text != NULL, NULL);
 #ifdef HAVE_GTK_310
-	tmp_toolbar_icon = gtk_image_new_from_icon_name ("gtk-close",
+	tmp_toolbar_icon = gtk_image_new_from_icon_name ("window-close",
                               GTK_ICON_SIZE_MENU);
 #else
 	tmp_toolbar_icon = gtk_image_new_from_stock(GTK_STOCK_CLOSE, 
@@ -897,7 +900,7 @@ void gui_notebook_main_switch_page(GtkNotebook * notebook,
 	if (stop_refresh)
 		return;
 
-	GS_message(("on_notebook_main_switch_page"));
+	XI_message(("on_notebook_main_switch_page"));
 	page_change = TRUE;
 	/* get data structure for new passage */
 	/*
@@ -958,7 +961,7 @@ void gui_notebook_main_switch_page(GtkNotebook * notebook,
 
 	navbar_versekey.module_name = g_string_assign(navbar_versekey.module_name,pt->text_mod);
 	navbar_versekey.key = g_string_assign(navbar_versekey.key,pt->text_commentary_key);
-	main_update_nav_controls(pt->text_commentary_key);
+	main_update_nav_controls(navbar_versekey.module_name->str, pt->text_commentary_key);
 
 	//sets the dictionary mod and key
 	main_display_dictionary(pt->dictlex_mod, pt->dictlex_key);
