@@ -58,6 +58,8 @@
 
 #include "gui/debug_glib_null.h"
 
+#include <glib/gstdio.h>
+
 // for one-time content rendering.
 extern ModuleCache::CacheMap ModuleMap;
 
@@ -78,6 +80,13 @@ int marked_cache_chapter = -1;
 
 int footnote, xref;
 
+// flag for having discovered (in)valid bible keys.
+// used for e.g. navigating from a bible w/apocrypha
+// to a tab with a non-apocrypha bible.
+gboolean valid_scripture_key = TRUE;
+const gchar *no_content =
+    N_("<br/><br/><center><i>This module has no content at this point.</i></center>");
+
 #define	HTML_START	\
 "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"> \
 <style type=\"text/css\"><!-- \
@@ -85,7 +94,8 @@ A { text-decoration:none } \
 *[dir=rtl] { text-align: right; } \
 body {background-color:%s;color:%s;} \
 a:link{color:%s} %s%s -->\
-</style></head><body>"
+</style>%s</head><body>"
+// 6 interpolable strings: bg/txt/link colors, block, renderHeader, external css.
 
 // CSS style blocks to control blocked strongs+morph output
 // BOTH is when the user wants to see both types of markup.
@@ -267,7 +277,7 @@ ClearImages(gchar *text)
 			while (s <= t)
 				*(s++) = ' ';
 		} else {
-			GS_message(("ClearImages: no img end: %s\n", s));
+			XI_message(("ClearImages: no img end: %s\n", s));
 			return;
 		}
 	}
@@ -292,12 +302,67 @@ ClearFontFaces(gchar *text)
 			while (s <= t)
 				*(s++) = ' ';
 		} else {
-			GS_message(("ClearFontFaces: no font end: %s\n", s));
+			XI_message(("ClearFontFaces: no font end: %s\n", s));
 			return;
 		}
 	}
 }
 
+//
+// retrieve the content of the module's personal css
+//
+static const char *stylefile =
+    "style.css";			// default name, per module.
+static const char *default_stylefile =
+    "default-style.css";		// default name, overall.
+
+const gchar *get_css_references(SWModule& module)
+{
+    static string css;		// static -> safe to return it
+
+    // assume nothing will be available.
+    css = "";
+    
+    // non-specific CSS for all module displays.
+    char *css_file = g_build_filename(settings.gSwordDir,
+				      default_stylefile, NULL);
+
+    if (g_file_test(css_file, G_FILE_TEST_EXISTS))
+    {
+	css += (string)"<link rel=\"stylesheet\" type=\"text/css\" href=\""
+#ifdef WIN32
+	    + "http://127.0.0.1:7878/"	// see main.c (sob)
+#else
+	    + "file:"
+#endif
+	    + css_file
+	    + "\" />";
+    }
+    g_free(css_file);
+
+    // construct path to module's CSS.
+    char *datapath = main_get_mod_config_entry(module.getName(), "AbsoluteDataPath");
+    char *prefcss  = main_get_mod_config_entry(module.getName(), "PreferredCSSXHTML");
+
+    // module-specific CSS.
+    css_file = g_build_filename(datapath, (prefcss ? prefcss : stylefile), NULL);
+
+    if (g_file_test(css_file, G_FILE_TEST_EXISTS))
+    {
+	css += (string)"<link rel=\"stylesheet\" type=\"text/css\" href=\""
+#ifdef WIN32
+	    + "http://127.0.0.1:7878/"	// see main.c (sob)
+#else
+	    + "file:"
+#endif
+	    + css_file
+	    + "\" />";
+    }
+    g_free(css_file);	// get rid of old one first.
+    
+    return css.c_str();
+}
+
 //
 // utility function for block_render() below.
 // having a word + annotation in hand, stuff them into the buffer.
@@ -461,7 +526,7 @@ block_render_secondary(const char *text,
 				end[2] = *(s+1);
 			again:
 				if ((t = strstr((char *)s, end)) == NULL) {
-					GS_warning(("No %s in %s\n", end, s));
+					XI_warning(("No %s in %s\n", end, s));
 					break;
                                 }
 
@@ -504,7 +569,7 @@ block_render_secondary(const char *text,
 			} else if (!strncmp(s+1, "small>", 6)) {
 				// strongs and morph are bounded by "<small>".
 				if ((t = strstr((char *)s, "</small>")) == NULL) {
-					GS_warning(("No </small> in %s\n", s));
+					XI_warning(("No </small> in %s\n", s));
 					break;
 				}
 				t += 8;
@@ -904,6 +969,7 @@ GTKEntryDisp::display(SWModule &imodule)
 				     ? DOUBLE_SPACE
 				     : ""))),
 			      imodule.getRenderHeader(),
+			      get_css_references(imodule),
 			      ((mf->old_font) ? mf->old_font : ""),
 			      mf->old_font_size_value,
 			      imodule.getDescription(),
@@ -917,6 +983,18 @@ GTKEntryDisp::display(SWModule &imodule)
 			      ((is_rtol && !ops->transliteration)
 			       ? "rtl"
 			       : "ltr"));
+
+	if (!valid_scripture_key) {
+		swbuf.append(no_content);
+		swbuf.append("</div></font></body></html>");
+		HtmlOutput((char *)swbuf.c_str(), gtkText, mf, NULL);
+		free_font(mf);
+		mf = NULL;
+		g_free(ops);
+		ops = NULL;
+		return 0;
+	}
+
 	//
 	// the rest of this routine is irrelevant if we are
 	// instead heading off to show a whole chapter
@@ -1173,7 +1251,7 @@ GTKChapDisp::getVerseAfter(SWModule &imodule)
 				 : "&nbsp; <a name=\"%d\"> </a>"),
 				0,
 				(char*)key->getText(),
-				((settings.versestyle)
+				(settings.versestyle
 				 ? settings.verse_num_font_size + settings.base_font_size
 				 : settings.base_font_size - 2),
 				settings.bible_verse_num_color,
@@ -1224,6 +1302,8 @@ GTKChapDisp::display(SWModule &imodule)
 		set_morph_order(imodule);
 	set_render_numbers(imodule, ops);
 
+	settings.versestyle = ops->verse_per_line;
+
 	// when strongs/morph are on, the anchor boundary must be smaller.
 	// or if main window is too small to keep curverse in-pane,
 	// of it the user wants really big fonts.
@@ -1256,6 +1336,7 @@ GTKChapDisp::display(SWModule &imodule)
 				   ? DOUBLE_SPACE
 				   : ""))),
 			    imodule.getRenderHeader(),
+			    get_css_references(imodule),
 			    ((mf->old_font) ? mf->old_font : ""),
 			    mf->old_font_size_value);
 	swbuf.append(buf);
@@ -1267,6 +1348,18 @@ GTKChapDisp::display(SWModule &imodule)
 			       : "ltr"));
 
 	main_set_global_options(ops);
+
+	if (!valid_scripture_key) {
+		swbuf.append(no_content);
+		swbuf.append("</div></font></body></html>");
+		HtmlOutput((char *)swbuf.c_str(), gtkText, mf, NULL);
+		free_font(mf);
+		mf = NULL;
+		g_free(ops);
+		ops = NULL;
+		return 0;
+	}
+
 	getVerseBefore(imodule);
 
 	for (key->setVerse(1);
@@ -1518,6 +1611,7 @@ DialogEntryDisp::display(SWModule &imodule)
 			      settings.link_color,
 			      (ops->doublespace ? DOUBLE_SPACE : ""),
 			      imodule.getRenderHeader(),
+			      get_css_references(imodule),
 			      ((mf->old_font) ? mf->old_font : ""),
 			      mf->old_font_size_value,
 			      settings.bible_verse_num_color,
@@ -1527,6 +1621,17 @@ DialogEntryDisp::display(SWModule &imodule)
 	swbuf.append(buf);
 	g_free(buf);
 
+	if (!valid_scripture_key) {
+		swbuf.append(no_content);
+		swbuf.append("</div></font></body></html>");
+		HtmlOutput((char *)swbuf.c_str(), gtkText, mf, NULL);
+		free_font(mf);
+		mf = NULL;
+		g_free(ops);
+		ops = NULL;
+		return 0;
+	}
+
 	//
 	// the rest of this routine is irrelevant if we are
 	// instead heading off to show a whole chapter
@@ -1623,17 +1728,7 @@ DialogChapDisp::display(SWModule &imodule)
 	    (curChapter != marked_cache_chapter))
 		marked_cache_fill(ModuleName, (gchar *)key->getShortText());
 
-	gint versestyle;
-	gchar *file = NULL, *style = NULL;
-
-	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
-	style = get_conf_file_item(file, ModuleName, "style");
-	if ((style) && !strcmp(style, "verse"))
-		versestyle = TRUE;
-	else
-		versestyle = FALSE;
-	g_free(style);
-	g_free(file);
+	gint versestyle = ops->verse_per_line;
 
 	main_set_global_options(ops);
 
@@ -1652,6 +1747,7 @@ DialogChapDisp::display(SWModule &imodule)
 				     ? DOUBLE_SPACE
 				     : ""))),
 			      imodule.getRenderHeader(),
+			      get_css_references(imodule),
 			      ((mf->old_font) ? mf->old_font : ""),
 			      mf->old_font_size_value);
 	swbuf.append(buf);
@@ -1662,6 +1758,17 @@ DialogChapDisp::display(SWModule &imodule)
 			       ? "rtl"
 			       : "ltr"));
 
+	if (!valid_scripture_key) {
+		swbuf.append(no_content);
+		swbuf.append("</div></font></body></html>");
+		HtmlOutput((char *)swbuf.c_str(), gtkText, mf, NULL);
+		free_font(mf);
+		mf = NULL;
+		g_free(ops);
+		ops = NULL;
+		return 0;
+	}
+
 	for (key->setVerse(1);
 	     (key->getBook() == curBook) && (key->getChapter() == curChapter) && !imodule.popError();
 	     imodule++) {
@@ -1819,7 +1926,7 @@ GTKPrintEntryDisp::display(SWModule &imodule)
 	GLOBAL_OPS * ops = main_new_globals(imodule.getName());
 
 	imodule.getRawEntry();	// snap to entry
-	GS_message(("%s",(const char *)imodule.getRawEntry()));
+	XI_message(("%s",(const char *)imodule.getRawEntry()));
 	main_set_global_options(ops);
 	mod_type = backend->module_type(imodule.getName());
 
@@ -1841,6 +1948,7 @@ GTKPrintEntryDisp::display(SWModule &imodule)
 			      settings.link_color,
 			      (ops->doublespace ? DOUBLE_SPACE : ""),
 			      imodule.getRenderHeader(),
+			      get_css_references(imodule),
 			      ((mf->old_font) ? mf->old_font : ""),
 			      mf->old_font_size_value,
 			      settings.bible_verse_num_color,
@@ -1890,6 +1998,7 @@ GTKPrintChapDisp::display(SWModule &imodule)
 			      settings.link_color,
 			      (ops->doublespace ? DOUBLE_SPACE : ""),
 			      imodule.getRenderHeader(),
+			      get_css_references(imodule),
 			      ((mf->old_font) ? mf->old_font : ""),
 			      mf->old_font_size_value);
 	swbuf.append(buf);
@@ -1923,7 +2032,7 @@ GTKPrintChapDisp::display(SWModule &imodule)
 			? "&nbsp; <a name=\"%d\" href=\"sword:///%s\">"
 			  "<font size=\"%+d\" color=\"%s\">%s%s%s%s%s%s%s</font></a>&nbsp;"
 			: "&nbsp; <a name=\"%d\"> </a>",
-				      key->getVerse(),
+			key->getVerse(),
 			(char*)key->getText(),
 			settings.verse_num_font_size + settings.base_font_size,
 			settings.bible_verse_num_color,
