@@ -37,6 +37,7 @@
 #include "main/module_dialogs.h"
 #include "main/settings.h"
 #include "main/parallel_view.h"
+#include "main/sword.h"
 
 #include "backend/sword_main.hh"
 
@@ -152,10 +153,14 @@ void main_set_global_options(GLOBAL_OPS * ops)
 	_set_global_option("Cross-references", ops->scripturerefs);
 	_set_global_option("Hebrew Vowel Points", ops->hebrewpoints);
 	_set_global_option("Hebrew Cantillation", ops->hebrewcant);
+
 	// always turn on headings in the engine (and later cache them).
 	// whether we display them or not is another matter (display.cc).
 	_set_global_option("Headings", 1);
+
 	_set_global_option("Words of Christ in Red", ops->words_in_red);
+	_set_global_option("Transliterated Forms", ops->xlit);
+	_set_global_option("Enumerations", ops->enumerated);
 
 	_set_global_textual("Transliteration", (ops->transliteration
 						? "Latin" : "Off"));
@@ -199,16 +204,14 @@ GLOBAL_OPS *main_new_globals(const gchar * mod_name)
 	    gui_of2tf(module_options[mod_name]["Strong's Numbers"].c_str());
 	ops->morphs =
 	    gui_of2tf(module_options[mod_name]["Morphological Tags"].c_str());
-	ops->greekaccents =
-	    gui_of2tf(module_options[mod_name]["Greek Accents"].c_str());
 	ops->lemmas =
 	    gui_of2tf(module_options[mod_name]["Lemmas"].c_str());
-	ops->hebrewpoints =
-	    gui_of2tf(module_options[mod_name]["Hebrew Vowel Points"].c_str());
-	ops->hebrewcant =
-	    gui_of2tf(module_options[mod_name]["Hebrew Cantillation"].c_str());
 	ops->transliteration =
 	    gui_of2tf(module_options[mod_name]["Transliteration"].c_str());
+	ops->xlit =
+	    gui_of2tf(module_options[mod_name]["Transliterated Forms"].c_str());
+	ops->enumerated =
+	    gui_of2tf(module_options[mod_name]["Enumerations"].c_str());
 
 	ops->variants_all =
 	    gui_of2tf(module_options[mod_name]["All Readings"].c_str());
@@ -234,11 +237,27 @@ GLOBAL_OPS *main_new_globals(const gchar * mod_name)
 	ops->xrefnotenumbers =
 	    (module_options[mod_name]["XrefNoteNumbers"] != "Off");
 
+	// more special case default on: heb/grk support.
+	ops->greekaccents =
+	    (module_options[mod_name]["Greek Accents"] != "Off");
+	ops->hebrewpoints =
+	    (module_options[mod_name]["Hebrew Vowel Points"] != "Off");
+	ops->hebrewcant =
+	    (module_options[mod_name]["Hebrew Cantillation"] != "Off");
+
+	// we prefer and assume paragraph layout.
+	// we take user preference, and alter our default for
+	// those modules showing proper configuration for it.
 	ops->verse_per_line = 
-	    (*(module_options[mod_name]["style"].c_str()) == 'v')
-	    ? 1	
-	    : 0;//  otherwise, paragraph style.
-	
+	    ((*(module_options[mod_name]["style"].c_str()) == 'v')
+	     ? 1
+	     : ((*(module_options[mod_name]["style"].c_str()) == 'p')
+		? 0
+		: (main_check_for_option(mod_name, "Feature", "NoParagraphs")
+		   ? 1	
+		   : 0)));	// default to paragraph style.
+
+	// options not from configuration: xiphos-specific capability.
 	ops->image_content =
 	    (*(module_options[mod_name]["Image Content"].c_str()) == '\0')
 	    ? -1	// "unknown"; otherwise, it's like the others.
