@@ -61,6 +61,8 @@ ConstructFlags(GLOBAL_OPS *ops)
 	flags |= (ops->commentary_by_chapter ? CommentaryChapter : 0);
 	flags |= (ops->doublespace           ? Doublespace : 0);
 	flags |= (ops->xrefnotenumbers       ? XrefNoteNumbers : 0);
+	flags |= (ops->xlit                  ? Xlit : 0);
+	flags |= (ops->enumerated            ? Enumerated : 0);
 	return flags;
 }
 
