@@ -24,6 +24,7 @@
 #endif
 #include <gtk/gtk.h>
 #include <swmgr.h>
+#include <swmodule.h>
 #include <versekey.h>
 
 
@@ -54,12 +55,16 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 	int book;
 	GtkTreeIter iter;
 	gint i,x;
-	VerseKey vkey;
 
 	if (!navbar.module_name)
 		return;
 
-	navbar.key = backend->get_valid_key(key);
+	SWModule *mod = backend->get_SWModule(navbar.module_name);
+	if (!mod) return;
+
+	VerseKey *vkey = (VerseKey *)mod->createKey();
+
+	navbar.key = backend->get_valid_key(navbar.module_name, key);
 	if (!navbar.is_dialog) {
 
 
@@ -71,24 +76,27 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 
 	do_display = FALSE;
 
-	vkey.setAutoNormalize(1);
-	vkey = key;
+	int t = backend->module_type(navbar.module_name);
+	if ((t == TEXT_TYPE) || (t == COMMENTARY_TYPE))
+		vkey->setAutoNormalize(1);
+	vkey->setText(key);
 
+	// we need the book index to highlight "active" in the pulldown.
 	if ((backend->module_has_testament(navbar.module_name, 1))
-	    && (vkey.getTestament() == 2))
-	        book = 39 + vkey.getBook();
+	    && (vkey->getTestament() == 2))
+	        book = vkey->BMAX[0] + vkey->getBook();
 	else
-	        book = vkey.getBook();
+	        book = vkey->getBook();
 
 	gtk_combo_box_set_active((GtkComboBox *)navbar.comboboxentry_book,
                                              book-1);
 
 	gtk_list_store_clear(GTK_LIST_STORE(chapter_store));
-	//char xtestament = vkey.Testament() ;
-	//char xbook = vkey.Book();
-	int xchapter = vkey.getChapter();
-	int xverse = vkey.getVerse();
-	x = (vkey.getChapterMax());
+	//char xtestament = vkey->Testament() ;
+	//char xbook = vkey->Book();
+	int xchapter = vkey->getChapter();
+	int xverse = vkey->getVerse();
+	x = (vkey->getChapterMax());
 	for(i=1; i <= x; i++) {
 		char *num = main_format_number(i);
 		gtk_list_store_append (GTK_LIST_STORE(chapter_store), &iter);
@@ -103,11 +111,11 @@ void main_navbar_set(NAVBAR navbar, const char * key)
                                              xchapter-1);
 
 	gtk_list_store_clear(GTK_LIST_STORE(verse_store));
-	//xtestament = vkey.Testament() ;
-	//xbook = vkey.Book();
-	xchapter = vkey.getChapter();
-	xverse = vkey.getVerse();
-	x = (vkey.getVerseMax());
+	//xtestament = vkey->Testament() ;
+	//xbook = vkey->Book();
+	xchapter = vkey->getChapter();
+	xverse = vkey->getVerse();
+	x = (vkey->getVerseMax());
 	for(i=1; i <= x; i++) {
 		char *num = main_format_number(i);
 		gtk_list_store_append (GTK_LIST_STORE(verse_store), &iter);
@@ -124,13 +132,20 @@ void main_navbar_set(NAVBAR navbar, const char * key)
 				navbar.key);
 	do_display = TRUE;
 	g_free(gkey);
+
+	delete vkey;
 }
 
 
 void main_navbar_fill_book_combo(NAVBAR navbar)
 {
-	VerseKey key;
-	VerseKey key_abrev;
+	if (!navbar.module_name)
+		return;
+
+	SWModule *mod = backend->get_SWModule(navbar.module_name);
+	if (!mod) return;
+
+	VerseKey *key = (VerseKey *)mod->createKey();
 	char *book = NULL;
 	GtkTreeIter iter;
 	int i = 0;
@@ -145,53 +160,44 @@ void main_navbar_fill_book_combo(NAVBAR navbar)
 	GtkTreeModel* book_model = gtk_combo_box_get_model(
 			GTK_COMBO_BOX(navbar.comboboxentry_book));
 	gtk_list_store_clear(GTK_LIST_STORE(book_model));
+
 	if (backend->module_has_testament(navbar.module_name, 1)) {
-		while (i < key.BMAX[0]) {
-			key.setTestament(1);
-			key.setBook(i+1);
-			book = strdup((const char *) key.getBookName());
-			char *mykey = g_strdup_printf("%s 1:1",book);
-			if (!main_get_raw_text(navbar.module_name, mykey)){
-				GS_message(("book-out: %s",book));
-				g_free(book);
-				g_free(mykey);
-				continue;
-			}
-			GS_message(("book: %s",book));
+		while (i < key->BMAX[0]) {
+			key->setTestament(1);
+			key->setBook(i+1);
+			book = strdup((const char *) key->getBookName());
+			XI_message(("book: %s",book));
 			gtk_list_store_append (GTK_LIST_STORE(book_model), &iter);
-			gtk_list_store_set(	GTK_LIST_STORE(book_model),
-						&iter,
-						0,
-						book,
-						-1);
+			gtk_list_store_set(GTK_LIST_STORE(book_model),
+					   &iter,
+					   0,
+					   book,
+					   -1);
+
 			++i;
 			g_free(book);
 		}
 	}
+
 	i = 0;
 	if (backend->module_has_testament(navbar.module_name, 2)) {
-		while (i < key.BMAX[1]) {
-			key.setTestament(2);
-			key.setBook(i+1);
-			book = strdup((const char *) key.getBookName());
-			char *mykey = g_strdup_printf("%s 1:1",book);
-			if (!main_get_raw_text(navbar.module_name, mykey)){
-				GS_message(("book-in: %s",book));
-				g_free(book);
-				g_free(mykey);
-				continue;
-			}
-			GS_message(("book: %s",book));
+		while (i < key->BMAX[1]) {
+			key->setTestament(2);
+			key->setBook(i+1);
+			book = strdup((const char *) key->getBookName());
+			XI_message(("book: %s",book));
 			gtk_list_store_append (GTK_LIST_STORE(book_model), &iter);
-			gtk_list_store_set(	GTK_LIST_STORE(book_model),
-						&iter,
-						0,
-						book,
-						-1);
+			gtk_list_store_set(GTK_LIST_STORE(book_model),
+					   &iter,
+					   0,
+					   book,
+					   -1);
 			++i;
 			g_free(book);
 		}
 	}
-	main_navbar_set(navbar,navbar.key);
+	main_navbar_set(navbar, navbar.key);
 	do_display = TRUE;
+
+	delete key;
 }
