@@ -25,6 +25,10 @@
 
 #include <gtk/gtk.h>
 
+#include <swmodule.h>
+#include <swkey.h>
+#include <versekey.h>
+
 #include "backend/sword_main.hh"
 #include "main/gtk_compat.h"
 
@@ -54,11 +58,14 @@ extern GtkWidget *sbIntChapter;
 extern GtkWidget *sbIntVerse;
 extern GtkWidget *entryIntLookup;
 
+SWBuf unknown_parallel = N_("Unknown parallel module: ");
+
 /******************************************************************************
  * static
  */
 
 BackEnd *backend_p;
+extern gchar *no_content;
 
 static const gchar *tf2of(int true_false)
 {
@@ -93,7 +100,7 @@ static void set_global_option(char * option, gboolean choice)
 	SWMgr *mgr = backend_p->get_mgr();
 	char *buf= g_strdup (option);
 
-//	GS_message (("option://%s\n\n",option));
+//	XI_message (("option://%s\n\n",option));
 
 	mgr->setGlobalOption(buf, on_off);
 
@@ -132,7 +139,7 @@ static void set_global_textual_reading (const char * option, int choice)
 		gui_generic_warning((char*)"Xiphos: invalid internal variant");
 		break;
 	}*/
-	GS_message (("set_global_textual_reading\noption://%s",option));
+	XI_message (("set_global_textual_reading\noption://%s",option));
 
 	mgr->setGlobalOption("Textual Variants", option);
 
@@ -178,9 +185,9 @@ gchar *main_parallel_change_verse(void)
 
 	sprintf(buf, "%s %d:%d", bookname, chapter, verse);
 
-	newbook = backend_p->key_get_book(buf);
-	chapter = backend_p->key_get_chapter(buf);
-	verse = backend_p->key_get_verse(buf);
+	newbook = backend_p->key_get_book(settings.parallel_list[0], buf);
+	chapter = backend_p->key_get_chapter(settings.parallel_list[0], buf);
+	verse   = backend_p->key_get_verse(settings.parallel_list[0], buf);
 
 	if (strcmp(bookname, newbook))
 		gtk_entry_set_text(GTK_ENTRY(entrycbIntBook), newbook);
@@ -300,6 +307,16 @@ void main_set_parallel_module_global_options(GtkCheckMenuItem * menuitem,
 		set_global_textual_reading (option, choice);
 	}
 
+	if (!strcmp(option,"Transliterated Forms")) {
+		settings.parallel_xlit = choice;
+		set_global_option(option, choice);
+	}
+
+	if (!strcmp(option,"Enumerations")) {
+		settings.parallel_enumerated = choice;
+		set_global_option(option, choice);
+	}
+
 
 	/* display change */
 	if (settings.dockedInt) {
@@ -334,7 +351,7 @@ void main_set_parallel_options_at_start(void)
 	while (tmp) {
 		char *option = g_strdup((char*)tmp->data);
 		g_strdelimit (option,"' ", '_');
-		//GS_message(("\n\n%s\n%s\n", (char*)tmp->data, option));
+		//XI_message(("\n\n%s\n%s\n", (char*)tmp->data, option));
 		value = xml_get_value("parallel", option);
 		int choice = (value ? atoi(value) : 0);
 		if (!strcmp((char*)tmp->data,"Textual Variants")) {
@@ -538,6 +555,26 @@ void main_load_g_ops_parallel(GtkWidget *menu)
 	g_signal_connect(G_OBJECT(item), "activate",
 	    G_CALLBACK(main_set_parallel_module_global_options),
 			   (char*) "All Readings");
+
+
+	item = gtk_check_menu_item_new_with_label(_("Transliterated Forms"));
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_xlit);
+	g_signal_connect(G_OBJECT(item), "activate",
+	    G_CALLBACK(main_set_parallel_module_global_options),
+			  (char*) "Transliterated Forms");
+
+
+	item = gtk_check_menu_item_new_with_label(_("Enumerations"));
+	gtk_widget_show(item);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(item), settings.parallel_enumerated);
+	g_signal_connect(G_OBJECT(item), "activate",
+	    G_CALLBACK(main_set_parallel_module_global_options),
+			  (char*) "Enumerations");
 }
 
 
@@ -615,7 +652,6 @@ void main_update_parallel_page(void)
 	gboolean is_rtol = FALSE;
 	GString *data;
 	MOD_FONT *mf;
-	SWBuf text;
 
 	settings.cvparallel = settings.currentverse;
 
@@ -634,8 +670,9 @@ void main_update_parallel_page(void)
 			// if a module was deleted, but still in parallels list,
 			// we will segfault when looking for content for the
 			// nonexistent module.  avoid this.
-			if (!main_is_module(mod_name)) {
-				GS_warning(("unknown parallel module %s\n", mod_name));
+			if (!backend_p->is_module(mod_name)) {
+				gui_generic_warning((unknown_parallel +
+						     (SWBuf)mod_name).c_str());
 				continue;
 			}
 
@@ -680,15 +717,23 @@ void main_update_parallel_page(void)
 			if (is_rtol)
 				g_string_append(data, "<br/><div align=right>");
 
-			backend_p->set_module_key(settings.parallel_list[modidx], settings.cvparallel);
-			text = "";
-			get_heading(text, backend_p, modidx);
-			g_string_append(data, text.c_str());
+			// does this verse exist for this module?
+			if (!backend_p->is_Bible_key(settings.parallel_list[modidx],
+						     settings.cvparallel, settings.cvparallel)) {
+				g_string_append(data, no_content);
+			}
+			else
+			{
+				SWBuf text("");
+				backend_p->set_module_key(settings.parallel_list[modidx], settings.cvparallel);
+				get_heading(text, backend_p, modidx);
+				g_string_append(data, text.c_str());
 
-			utf8str = backend_p->get_render_text(mod_name, settings.currentverse);
-			if (utf8str) {
-				g_string_append(data, utf8str);
-				g_free(utf8str);
+				utf8str = backend_p->get_render_text(mod_name, settings.currentverse);
+				if (utf8str) {
+				    g_string_append(data, utf8str);
+				    g_free(utf8str);
+				}
 			}
 
 			if (is_rtol)
@@ -733,6 +778,13 @@ void main_update_parallel_page(void)
 
 static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_count, gint fraction)
 {
+	// identify the module whose v11n will drive us.
+	// should be 1st parallel module.
+	// it would be really weird if that's missing, but be ready anyhow.
+	char *module_name = (settings.parallel_list
+			     ? settings.parallel_list[0]
+			     : settings.MainWindowModule);
+
 	gchar  	*utf8str,
 		*textColor,
 		*tmpkey,
@@ -746,6 +798,18 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 
 	if (!gtk_widget_get_realized(GTK_WIDGET(widgets.notebook_bible_parallel))) return;
 
+	// need #verses to process in this chapter.
+	SWModule *mod = backend->get_SWModule(module_name);
+	if (!mod) return;
+
+	VerseKey *vkey = (VerseKey *)mod->createKey();
+	int xverses;
+
+	vkey->setAutoNormalize(1);
+	vkey->setText(key);
+	xverses = (vkey->getVerseMax());
+	delete vkey;
+
 	is_module     = g_new(gboolean, parallel_count);
 	is_rtol       = g_new(gboolean, parallel_count);
 	is_bible_text = g_new(gboolean, parallel_count);
@@ -763,26 +827,30 @@ static void interpolate_parallel_display(SWBuf& text, gchar *key, gint parallel_
 			    (main_get_mod_type(settings.parallel_list[modidx])
 			     == TEXT_TYPE);
 		}
+		else
+		{
+			gui_generic_warning((unknown_parallel +
+					     (SWBuf)settings.parallel_list[modidx]).c_str());
+		}
 	}
 
-	// need #verses to process in this chapter.
-	VerseKey vkey;
-	int xverses;
+	// frankly, we're faking it here.
+	// we have potentially variable v11n among the parallel modules.
 
-	vkey.setAutoNormalize(1);
-	vkey = key;
-	xverses = (vkey.getVerseMax());
+	// but we must validate a key in some vaguely consistent manner.
+	// arbitrarily, we have picked the 1st.
+	// it's consistent, but very possibly wrong for all but the 1st.
+	tmpkey = backend_p->get_valid_key(module_name, key);
 
-	tmpkey = backend_p->get_valid_key(key);
-	cur_verse = backend_p->key_get_verse(tmpkey);
-	cur_chapter = backend_p->key_get_chapter(tmpkey);
-	cur_book = backend_p->key_get_book(tmpkey);
+	cur_book    = backend_p->key_get_book(module_name, tmpkey);
+	cur_chapter = backend_p->key_get_chapter(module_name, tmpkey);
+	cur_verse   = backend_p->key_get_verse(module_name, tmpkey);
 	settings.intCurVerse = cur_verse;
 
 	for (verse = 1; verse <= xverses; ++verse) {
 		snprintf(tmpbuf, 255, "%s %d:%d", cur_book, cur_chapter, verse);
 		free(tmpkey);
-		tmpkey = backend_p->get_valid_key(tmpbuf);
+		tmpkey = backend_p->get_valid_key(settings.parallel_list[0], tmpbuf);
 
 		text += "<tr valign=\"top\">";
 
@@ -1043,5 +1111,4 @@ void main_init_parallel_view(void)
 void main_delete_parallel_view(void)
 {
 	delete backend_p;
-
 }
