@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.cc - glue  (: very sticky :)
  *
- * Copyright (C) 2004-2010 Xiphos Developer Team
+ * Copyright (C) 2004-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,22 +26,8 @@
 #include <regex.h>
 #include <swbuf.h>
 #include <swmodule.h>
-#ifdef USE_GTKMOZEMBED
-#ifdef WIN32
-#include "geckowin/gecko-html.h"
-#else
-#include "gecko/gecko-html.h"
-#endif
-#else
-#ifdef __cplusplus
-extern "C" {
-#endif
-#include <gtkhtml/gtkhtml.h>
-#include "gui/html.h"
-#ifdef __cplusplus
-}
-#endif
-#endif
+
+#include "xiphos_html/xiphos_html.h"   
 
 #include "main/previewer.h"
 #include "main/search_dialog.h"
@@ -66,7 +52,7 @@ extern "C" {
 #define SEARCHING _("Searching the ")
 #define SMODULE _(" Module")
 #define FINDS _("found in ")
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"></head>"
+#define	HTML_START	"<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><STYLE type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></STYLE></head>"
 
 static BackEnd *backendSearch = NULL;
 
@@ -83,7 +69,6 @@ static GList *list_of_finds;
 static GList *list_for_bookmarking = NULL;
 
 
-
 /******************************************************************************
  * Name
  *   main_export_current_adv_search
@@ -120,7 +105,7 @@ gboolean main_export_current_adv_search (GString * str, gboolean html, gboolean
 
 		while (verses) {
 			list_item = (RESULTS *) verses->data;
-			if (main_is_Bible_key(list_item->key)) {
+			if (main_is_Bible_key(list_item->module, list_item->key)) {
 				ret = TRUE;
 				if (first_entry) {
 					if (html)
@@ -192,7 +177,7 @@ void main_save_current_adv_search_as_bookmarks (void)
 
 		while (verses) {
 			list_item = (RESULTS *) verses->data;
-			if (main_is_Bible_key(list_item->key)) {
+			if (main_is_Bible_key(list_item->module, list_item->key)) {
 				if (first_entry) {
 					module_name = g_strdup(list_item->module);
 					first_entry = FALSE;
@@ -264,8 +249,7 @@ void main_range_text_changed(GtkEditable * editable)
 
 	gtk_list_store_clear(store_list_ranges);
 	entry = gtk_entry_get_text(GTK_ENTRY(editable));
-	//count = start_parse_range_list(entry);
-	tmp = backend->parse_range_list(entry);
+	tmp = backend->parse_range_list(settings.MainWindowModule, entry);
 	while (tmp) {
 		buf = (gchar*)tmp->data;
 		if (!buf)
@@ -309,7 +293,7 @@ static void set_search_global_option(const gchar * option, gboolean choice)
 		on_off = "Off";
 	}
 	mgr->setGlobalOption(option, on_off);
-	GS_print(("option = %s is %s\n",option,on_off));
+	XI_print(("option = %s is %s\n",option,on_off));
 }
 
 
@@ -334,11 +318,11 @@ void main_save_modlist(void)
 	gchar *text1 = NULL;
 	gchar *text2 = NULL;
 	GtkTreeModel *model;
-	GtkListStore *list_store;
+	//GtkListStore *list_store;
 	GtkTreeIter iter;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
-	list_store = GTK_LIST_STORE(model);
+	//list_store = GTK_LIST_STORE(model);
 
 	if (!gtk_tree_model_get_iter_first(model, &iter))
 		return;
@@ -346,7 +330,7 @@ void main_save_modlist(void)
 		gtk_tree_model_get(model, &iter,
 				   0, &text1, 1, &text2, -1);
 		xml_set_list_item("modlists", "modlist", text1, text2);
-		GS_warning(("%s",text2));
+		XI_warning(("%s",text2));
 		g_free(text1);
 		g_free(text2);
 	} while (gtk_tree_model_iter_next(model, &iter));
@@ -376,13 +360,13 @@ void main_save_range(void)
 	gchar *text1 = NULL;
 	gchar *text2 = NULL;
 	GtkTreeModel *model;
-	GtkListStore *list_store;
+	//GtkListStore *list_store;
 	GtkTreeIter iter;
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW
 				    (search1.list_range_name));
-	list_store = GTK_LIST_STORE(model);
+	//list_store = GTK_LIST_STORE(model);
 
 	if (!gtk_tree_model_get_iter_first(model, &iter))
 		return;
@@ -391,7 +375,7 @@ void main_save_range(void)
 				   0, &text1, 1, &text2, -1);
 
 		xml_set_list_item("ranges", "range", text1, text2);
-		GS_warning(("%s",text2));
+		XI_warning(("%s",text2));
 		g_free(text1);
 		g_free(text2);
 	} while (gtk_tree_model_iter_next(model, &iter));
@@ -441,7 +425,13 @@ void main_delete_range(void)
 			      _("Are you sure you want to delete this range?"),
 			      name_string);
 
-	if (gui_yes_no_dialog(str, (char *)GTK_STOCK_DIALOG_WARNING)) {
+	if (gui_yes_no_dialog(str, (char *) 
+#ifdef HAVE_GTK_310 
+	          "dialog-warning"          
+#else
+	          GTK_STOCK_DIALOG_WARNING
+#endif	
+	            )) {
 		gtk_list_store_remove(list_store, &selected);
 		xml_remove_node("ranges", "range", name_string);
 		--search1.list_rows;
@@ -651,7 +641,7 @@ void main_change_mods_select_label(char *mod_name)
 {
 	gchar *str;
 
-	if (GTK_TOGGLE_BUTTON(search1.rb_current_module)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_current_module))) {
 		str = g_strdup_printf("<b>%s</b>%s",Q_("Search: "),mod_name);
 		gtk_label_set_markup(GTK_LABEL(search1.label_mod_select), str);
 		g_free(str);
@@ -700,7 +690,13 @@ void main_delete_module(GtkTreeView *treeview)
 			      _("Remove Module?"),
 			      _("Are you sure you want to remove the selected module?"));
 
-	if (gui_yes_no_dialog(str, (char *)GTK_STOCK_DIALOG_WARNING)) {
+	if (gui_yes_no_dialog(str, (char*) 
+#ifdef HAVE_GTK_310 
+	          "dialog-warning"          
+#else
+	          GTK_STOCK_DIALOG_WARNING
+#endif	
+	            )) {
 		gtk_list_store_remove(list_store, &selected);
 
 		mods = get_current_list(treeview);
@@ -732,7 +728,7 @@ void main_add_mod_to_list(GtkWidget * tree_widget, gchar * mod_name)
 	GtkTreeIter selected_modules_lists;
 	GtkListStore *list_store;
 	GtkListStore *store_modules_lists;
-	gchar *mod_description = NULL;
+	const gchar *mod_description = NULL;
 	gchar *mod_list = NULL;
 	GList *mods = NULL;
 	GtkTreeSelection *selection_modules_lists;
@@ -789,7 +785,7 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 				  GtkWidget * tree_widget)
 {
 	gchar *mod = NULL;
-	gchar *mod_description = NULL;
+	const gchar *mod_description = NULL;
 	gchar *mod_list = NULL;
 	GList *mods = NULL;
 	GtkListStore *store_modules_lists;
@@ -823,12 +819,12 @@ void main_mod_selection_changed(GtkTreeSelection * selection,
 	if (gtk_tree_model_iter_has_child(model, &selected))
 		return;
 
-	gtk_tree_model_get(model, &selected, 0, &mod, -1);
+	gtk_tree_model_get(model, &selected, UTIL_COL_MODULE, &mod, -1);
 	if (mod) {
 		mod_description =
 			backendSearch->module_description(mod);
 
-		if (GTK_TOGGLE_BUTTON(search1.rb_current_module)->active) {
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_current_module))) {
 			search1.search_mod = g_strdup(mod);
 			search1.module_count = 1;
 		} else {
@@ -888,7 +884,7 @@ void main_selection_finds_list_changed(GtkTreeSelection *
 	gtk_tree_model_get(model, &selected, 0, &text, -1);
 	path = gtk_tree_model_get_path(model,&selected);
 	path_str = gtk_tree_path_to_string(path);
-	GS_message(("\npath: %s\ntext: %s",path_str,text));
+	XI_message(("\npath: %s\ntext: %s",path_str,text));
 	tmp = g_list_nth(list_of_finds,atoi(path_str));
 	tmp = (GList*)tmp->data;
 	add_module_finds(tmp);
@@ -925,15 +921,15 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 {
 	gchar *text, *buf, *module, *key;
 	GString *text_str;
-	gint textlen;
+	//gint textlen;
 	//GtkTreeModel *model;
 	GtkTreeIter selected;
 
  	if (!gtk_tree_selection_get_selected (selection, &model, &selected))
 		return;
 	gtk_tree_model_get(model, &selected, 0, &text, -1);
-	GS_message(("\ntext: %s", text));
-	textlen = strlen(text);
+	XI_message(("\ntext: %s", text));
+	//textlen = strlen(text);
 	module = text;
 
 	// first `:' finds end of module name.
@@ -954,21 +950,26 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 	text_str = g_string_new(backendSearch->get_render_text(module,key));
 	mark_search_words(text_str);
 
-#ifdef USE_GTKMOZEMBED
-	GString *html_text = g_string_new(HTML_START);
+	GString *html_text = g_string_new("");
+	MOD_FONT *mf = get_font(module);
+	g_string_printf(html_text,
+			HTML_START
+			"<body text=\"%s\" bgcolor=\"%s\" link=\"%s\">"
+			"<font face=\"%s\" size=\"%+d\">",
+			settings.bible_text_color, settings.bible_bg_color,
+			settings.link_color,
+			((mf->old_font) ? mf->old_font : ""),
+			mf->old_font_size_value);
+	free_font(mf);
 	g_string_append(html_text, text_str->str);
-	g_string_append(html_text, "</html>");
-	gecko_html_open_stream(GECKO_HTML(search1.preview_html), "text/html");
-	gecko_html_write(GECKO_HTML(search1.preview_html),
+	g_string_append(html_text, "</font></body></html>");	
+	XIPHOS_HTML_OPEN_STREAM(search1.preview_html, "text/html");
+	XIPHOS_HTML_WRITE(search1.preview_html,
 			 html_text->str, html_text->len);
-	gecko_html_close(GECKO_HTML(search1.preview_html));
+	XIPHOS_HTML_CLOSE(search1.preview_html);
 	g_string_free(html_text, TRUE);
-#else
-	gtk_html_load_from_string(GTK_HTML(search1.preview_html),
-				  text_str->str, text_str->len);
-#endif
 
-	GS_message(("main_finds_verselist_selection_changed: %s %s", module, key));
+	XI_message(("main_finds_verselist_selection_changed: %s %s", module, key));
 
 	if (text)
 		g_free(text);
@@ -993,8 +994,8 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
  *   void
  */
 
-void main_selection_modules_lists_changed(GtkTreeSelection *
-					    selection, gpointer data)
+void main_selection_modules_lists_changed(GtkTreeSelection * selection,
+					  gpointer data)
 {
 	gchar *name, *modules;
 	GList *tmp = NULL, *tmp2;
@@ -1037,7 +1038,7 @@ void main_selection_modules_lists_changed(GtkTreeSelection *
 	}
 	g_list_free(tmp2);
 
-	if (!GTK_TOGGLE_BUTTON(search1.rb_current_module)->active)
+	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_current_module)))
 		main_add_modlist_to_label();
 	g_free(name);
 	g_free(modules);
@@ -1087,9 +1088,9 @@ void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data)
 	gchar *mod_list_str = NULL;
 	const gchar *name = NULL;
 
-	if (!GTK_TOGGLE_BUTTON(search1.rb_custom_list)->active)
+	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_custom_list)))
 		return;
-	name = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(combobox)->child));
+	name = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(combobox))));
 	mod_list = get_custom_list_from_name(name);
 	mod_list_str = get_modlist_string(mod_list);
 	if (strlen(mod_list_str) > 60)
@@ -1123,19 +1124,16 @@ void main_comboboxentry2_changed(GtkComboBox * combobox, gpointer user_data)
 static void check_search_global_options(void)
 {
 	set_search_global_option("Strong's Numbers",
-				 GTK_TOGGLE_BUTTON(search1.
-						   cb_include_strongs)->
-				 active);
+				 gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(search1.
+						   cb_include_strongs)));
 
 	set_search_global_option("Morphological Tags",
-				 GTK_TOGGLE_BUTTON(search1.
-						   cb_include_morphs)->
-				 active);
+				 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.
+						   cb_include_morphs)));
 
 	set_search_global_option("Footnotes",
-				 GTK_TOGGLE_BUTTON(search1.
-						   cb_include_footnotes)->
-				 active);
+				 gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.
+						   cb_include_footnotes)));
 }
 
 
@@ -1229,12 +1227,15 @@ static void set_up_dialog_search(GList *modlist)
 
 	//gui_begin_html(search1.results_html, TRUE);
 	backendSearch->clear_scope();
-	if (GTK_TOGGLE_BUTTON(search1.rb_custom_range)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_custom_range))) {
 		// if any non-bible, non-commentary modules are in use,
 		// we must not respect this "custom range" selector.
 		gboolean range_ok = TRUE;
+		gchar *name_for_range = NULL;
 
 		while (modlist) {
+			if (name_for_range == NULL)
+				name_for_range = (char*)modlist->data;
 			int mod_type = backend->module_type((char*)modlist->data);
 			if ((mod_type != TEXT_TYPE) &&
 			    (mod_type != COMMENTARY_TYPE)) {
@@ -1247,18 +1248,18 @@ static void set_up_dialog_search(GList *modlist)
 		if (range_ok) {
 			backendSearch->clear_search_list();
 			label =
-			    gtk_entry_get_text(GTK_ENTRY(GTK_BIN(search1.combo_range)->child));
+			    gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child (GTK_BIN(search1.combo_range))));
 			range =
 			    (gchar *) xml_get_list_from_label("ranges", "range",
 							      label);
 			if (range) {
-				backendSearch->set_range(range);
+				backendSearch->set_range(name_for_range, range);
 				backendSearch->set_scope2range();
 			}
 		}
 	}
 
-	else if (GTK_TOGGLE_BUTTON(search1.rb_last)->active) {
+	else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_last))) {
 		backendSearch->set_scope2last_search();
 	}
 
@@ -1268,29 +1269,6 @@ static void set_up_dialog_search(GList *modlist)
 }
 
 
-
-/******************************************************************************
- * Name
- *   main_get_rendered_text
- *
- * Synopsis
- *   #include "main/sword.h"
- *
- *   char *main_get_rendered_text(char *module_name, char *key)
- *
- * Description
- *
- *
- * Return value
- *   char *
- */
-
-char *main_get_search_rendered_text(char *module_name, char *key)
-{
-	check_search_global_options();
-	return backendSearch->get_render_text(module_name, key);
-}
-
 static
 void _clear_find_lists(void)
 {
@@ -1302,7 +1280,7 @@ void _clear_find_lists(void)
 		tmp = (GList*) list_of_finds->data;
 		while (tmp) {
 			tmp_buf = (char*) tmp->data;
-			GS_message(("%s",tmp_buf));
+			XI_message(("%s",tmp_buf));
 			if (tmp_buf) g_free(tmp_buf);
 			tmp = g_list_next(tmp);
 		}
@@ -1326,7 +1304,7 @@ void _clear_bookmarking_lists(void)
 		tmp = (GList*) list_for_bookmarking->data;
 		while (tmp) {
 			results = (RESULTS*) tmp->data;
-			GS_message(("%s://%s",results->module,results->key));
+			XI_message(("%s://%s",results->module,results->key));
 			if (results->module) g_free(results->module);
 			if (results->key) g_free(results->key);
 			if (results) g_free (results);
@@ -1388,49 +1366,49 @@ void main_do_dialog_search(void)
 
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(search1.notebook), 1);
 	search_type =
-	    (GTK_TOGGLE_BUTTON(search1.rb_regexp)->active
+	    (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_regexp))
 	     ? 0
-	     : (GTK_TOGGLE_BUTTON(search1.rb_exact_phrase)->active
+	     : (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_exact_phrase))
 		? -1
-		: (GTK_TOGGLE_BUTTON(search1.rb_words)->active
+		: (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_words))
 		   ? -2
-		   : (GTK_TOGGLE_BUTTON(search1.rb_optimized)->active
+		   : (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_optimized))
 		      ? -4
 		      : -3 /* fallthrough to attribute */ ))));
-	GS_message(("search_type = %d", search_type));
+	XI_message(("search_type = %d", search_type));
 
 	search_params =
-	    GTK_TOGGLE_BUTTON(search1.cb_case_sensitive)->active ? 0 : REG_ICASE;
+	    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.cb_case_sensitive)) ? 0 : REG_ICASE;
 
 	// For attribute-based searches, e.g. "Word//Lemma/G140",
 	// we must constrain the match to whole words.  Otherwise,
 	// we will inadvertently return e.g. 140 plus 1401 and 1404.
 	if (search_type == -3) {
-		if (GTK_TOGGLE_BUTTON(search1.rb_strongs)->active) {
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_strongs))) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 			attribute_search_string = g_strdup_printf(
 					"Word//Lemma./%s",
 					search_string);
-		} else if (GTK_TOGGLE_BUTTON(search1.rb_morphs)->active) {
+		} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_morphs))) {
 			search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 			attribute_search_string = g_strdup_printf(
 					"Word//Morph/%s",
 					search_string);
-		} else if (GTK_TOGGLE_BUTTON(search1.rb_footnotes)->active) {
+		} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_footnotes))) {
 			attribute_search_string = g_strdup_printf(
 					"Footnote//body/%s",
 					search_string);
 		}
-		GS_message(("%s",attribute_search_string));
+		XI_message(("%s",attribute_search_string));
 	}
 
-	if (GTK_TOGGLE_BUTTON(search1.rb_custom_list)->active) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_custom_list))) {
 		const gchar *name;
 		name =
 		    gtk_entry_get_text(GTK_ENTRY(
-				GTK_BIN(search1.combo_list)->child));
+				gtk_bin_get_child (GTK_BIN(search1.combo_list))));
 		search_mods = get_custom_list_from_name(name);
-	} else if (GTK_TOGGLE_BUTTON(search1.rb_mod_list)->active) {
+	} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(search1.rb_mod_list))) {
 		search_mods = get_current_list(GTK_TREE_VIEW(search1.listview_modules));
 	} else
 		search_mods = get_current_search_mod();
@@ -1487,17 +1465,17 @@ void main_do_dialog_search(void)
 				gui_generic_warning(msg);
 			}
 		}
-		GS_message(("search_type = %d",search_type));
+		XI_message(("search_type = %d",search_type));
 
 		finds = backendSearch->do_module_search(module,
-					(attribute_search_string
-					 ? mgr->getModule(module)->
-						StripText(attribute_search_string)
-					 : mgr->getModule(module)->
-						StripText(search_string)),
-					search_type,
-					search_params,
-					TRUE);
+							(attribute_search_string
+							 ? mgr->getModule(module)->
+							   stripText(attribute_search_string)
+							 : mgr->getModule(module)->
+							   stripText(search_string)),
+							search_type,
+							search_params,
+							TRUE);
 
 		tmp_list = g_list_first(tmp_list);
 		tmp_list = NULL;
@@ -1507,7 +1485,8 @@ void main_do_dialog_search(void)
 		mod_type = backendSearch->module_type(module);
 		while ((key_buf = backendSearch->get_next_listkey()) != NULL) {
 			if (mod_type == TEXT_TYPE)
-				g_string_printf(str, "%s: %s  %s", module,  key_buf, backendSearch->get_strip_text(module, key_buf));
+				g_string_printf(str, "%s: %s  %s", module, key_buf,
+						backendSearch->get_strip_text(module, key_buf));
 			else
 				g_string_printf(str, "%s: %s", module,  key_buf);
 			tmp_list = g_list_append(tmp_list, (char*) g_strdup(str->str));
@@ -1523,8 +1502,7 @@ void main_do_dialog_search(void)
 
 		// add number of hits in each module to finds listview
 		num = main_format_number(finds);
-		g_string_printf(str, "%s %s %s",
-				num, FINDS, module);
+		g_string_printf(str, "%s %s %s", num, FINDS, module);
 		g_free(num);
 		gtk_list_store_append(list_store, &iter);
 		gtk_list_store_set(list_store,
@@ -1578,9 +1556,8 @@ void main_open_search_dialog(void)
 		backendSearch = new BackEnd();
 
 		/* create and show search dialog */
-		gui_create_search_dialog();
 		backendSearch->init_SWORD(2);
-
+		gui_create_search_dialog();
 
 		/* initiate module count to 0 */
 		search1.module_count = 0;
@@ -1599,7 +1576,7 @@ void main_open_search_dialog(void)
 
 		is_running = TRUE;
 	} else
-		gdk_window_raise(GTK_WIDGET(search1.dialog)->window);
+		gdk_window_raise(GDK_WINDOW(search1.dialog));
 	search_dialog = TRUE;
 }
 
@@ -1611,6 +1588,7 @@ void main_close_search_dialog(void)
 	delete backendSearch;
 	backendSearch = NULL;
 }
+
 /******************************************************************************
  * Name
  *  search_percent_update
