@@ -110,14 +110,16 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	}
 
 	/* set gSwordDir to $home + .xiphos */
-	settings.gSwordDir = g_strdup_printf("%s/%s", settings.homedir, XI_DIR);
+	settings.gSwordDir = g_build_filename(settings.homedir, XI_DIR, NULL);
 
 	/* if gSwordDir does not exist, create it. */
 	if (g_access(settings.gSwordDir, F_OK) == -1) {
 		if ((Mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
 			char msg[300];
 			gui_init(argc, argv);
-			sprintf(msg, _("Xiphos can not create  .xiphos:\n%s\n\nXiphos cannot continue."),
+			sprintf(msg, _("Xiphos can not create directory "
+				       XI_DIR
+				       ":\n%s\n\nXiphos cannot continue."),
 				strerror(errno));
 			gui_generic_warning_modal(msg);
 			/* if we can not create gSwordDir exit */
@@ -195,7 +197,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 	    (g_access(settings.fnconfigure, F_OK) == -1) ||
 	    new_configs) {
 		/* must be first run */
-		GS_print((buf_says_empty
+		XI_print((buf_says_empty
 			  ? "\nSETTINGS FILE EXISTS BUT IS EMPTY - RECREATING.\n"
 			  : "\nFirst Run: need to create settings!\n"));
 		settings.first_run = TRUE;
@@ -262,7 +264,7 @@ int settings_init(int argc, char **argv, int new_configs, int new_bookmarks)
 		}
 		if (test != NULL) {
 			g_setenv("LC_ALL", test, TRUE);
-			GS_message(("set locale to %s", settings.special_locale));
+			XI_message(("set locale to %s", settings.special_locale));
 		}
 	}
 
@@ -298,15 +300,13 @@ int init_bookmarks(int new_bookmarks)
 {
 	//GNode *bookmark_tree = NULL;
 	char *file_buf = NULL;
-	char *removed = NULL;
-	//int load_old = FALSE;
 
 	settings.load_xml_bookmarks = FALSE;
 
 	/* set bookmarks dir to settings.gSwordDir + /bookmarks */
 	settings.swbmDir = g_strdup_printf("%s/%s", settings.gSwordDir, "bookmarks");
 
-	/* if .xiphos-2.0/bookmarks does not exist create it */
+	/* if .xiphos/bookmarks does not exist create it */
 	if (g_access(settings.swbmDir, F_OK) == -1) {
 		if ((Mkdir(settings.swbmDir, S_IRWXU)) == -1) {
 			g_warning("can't create bookmarks dir");
@@ -330,20 +330,6 @@ int init_bookmarks(int new_bookmarks)
 		settings.load_xml_bookmarks = TRUE;
 	}
 
-	/* check for Bibletime bookmarks */
-	settings.have_bibletime = FALSE;
-	file_buf = g_strdup_printf("%s/%s", settings.homedir,
-				   ".bibletime/bookmarks.xml");
-	if (g_access(file_buf, F_OK) == 0) {
-		settings.have_bibletime = TRUE;
-	}
-
-	/* clean up */
-	if (file_buf)
-		g_free(file_buf);
-	if (removed)
-		g_free(removed);
-
 	return 1;
 }
 
@@ -872,6 +858,20 @@ void load_settings_structure(void)
 		settings.parallel_greekaccents = 1;
 	}
 
+	if ((buf = xml_get_value("parallel", "Transliterated_Forms")))
+		settings.parallel_xlit = atoi(buf);
+	else {
+		xml_add_new_item_to_section("parallel", "Transliterated_Forms", "0");
+		settings.parallel_xlit = 0;
+	}
+
+	if ((buf = xml_get_value("parallel", "Enumerations")))
+		settings.parallel_enumerated = atoi(buf);
+	else {
+		xml_add_new_item_to_section("parallel", "Enumerations", "0");
+		settings.parallel_enumerated = 0;
+	}
+
 	/*  Misc stuff  */
 
 	settings.showtexts = atoi((buf = xml_get_value("misc", "showtexts")) ? buf : "1");
