@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * utilities.c - support functions
  *
- * Copyright (C) 2000-2010 Xiphos Developer Team
+ * Copyright (C) 2000-2014 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -38,6 +37,7 @@
 #include "gui/sidebar.h"
 #include "gui/tabbed_browser.h"
 #include "gui/utilities.h"
+#include "gui/dialog.h"
 
 #include "main/sidebar.h"
 #include "main/configs.h"
@@ -144,9 +144,16 @@ void main_display_verse_list_in_sidebar(gchar * key,
 	GtkTreeIter iter;
 	RESULTS *list_item;
 
+	/* improper xref encoding, not BCV: gets null list from Sword. */
+	if (verse_list == NULL) {
+		gui_generic_warning(_("Module error: Unusable xref encoding.\n"
+				      "Please report this, with module & verse"));
+		return;
+	}
+
 	is_search_result = FALSE;
 
-	GS_warning(("verse_list = %s",verse_list));
+	XI_warning(("verse_list = %s",verse_list));
 	list_of_verses = g_list_first(list_of_verses);
 	if (list_of_verses) {
 		GList *chaser = list_of_verses;
@@ -175,7 +182,7 @@ void main_display_verse_list_in_sidebar(gchar * key,
 		verse_list += 4;
 	
 	if ((*verse_list != '/') &&
-	    ((tmp = backend->parse_verse_list(verse_list, key)) != NULL)) {
+	    ((tmp = backend->parse_verse_list(module_name, verse_list, key)) != NULL)) {
 		// normal verse list.
 		while (tmp != NULL) {
 			gtk_list_store_append(list_store, &iter);
@@ -249,38 +256,33 @@ static void add_children_to_tree(GtkTreeModel * model, GtkTreeIter iter,
 			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
 			   -1);
 
-	GS_message(("offset: %ld",backend->get_treekey_offset()));
-	GS_message(("%s",backend->display_mod->Name()));
+	XI_message(("offset: %ld",backend->get_treekey_offset()));
+	XI_message(("%s",backend->display_mod->getName()));
 	if (backend->treekey_first_child(offset)) {
-		GS_message(("treekey_first_child1 %s",mod_name));
+		XI_message(("treekey_first_child1 %s",mod_name));
 
 		offset = backend->get_treekey_offset();
 
-		GS_message(("offset: %ld",offset));
+		XI_message(("offset: %ld",offset));
 
 		sprintf(buf, "%lu", offset);
 		tmpbuf = backend->treekey_get_local_name(offset);
 		gtk_tree_store_append(GTK_TREE_STORE(model),
 				      &child_iter, &iter);
 		if (backend->treekey_has_children(offset)) {
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CLOSED_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CAPTION,
-					   (gchar *) tmpbuf, COL_MODULE,
-					   (gchar *) mod_name,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CAPTION, (gchar *) tmpbuf,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) buf,
 					   -1);
 		} else {
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_helpdoc,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_helpdoc,
 					   COL_CLOSED_PIXBUF, NULL,
-					   COL_CAPTION,
-					   (gchar *) tmpbuf, COL_MODULE,
-					   (gchar *) mod_name,
+					   COL_CAPTION, (gchar *) tmpbuf,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) buf,
 					   -1);
 		}
@@ -294,24 +296,19 @@ static void add_children_to_tree(GtkTreeModel * model, GtkTreeIter iter,
 		gtk_tree_store_append(GTK_TREE_STORE(model),
 				      &child_iter, &iter);
 		if (backend->treekey_has_children(offset)) {
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CLOSED_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CAPTION,
-					   (gchar *) tmpbuf, COL_MODULE,
-					   (gchar *) mod_name,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CAPTION, (gchar *) tmpbuf,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) buf,
 					   -1);
 		} else {
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_helpdoc,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_helpdoc,
 					   COL_CLOSED_PIXBUF, NULL,
-					   COL_CAPTION,
-					   (gchar *) tmpbuf, COL_MODULE,
-					   (gchar *) mod_name,
+					   COL_CAPTION, (gchar *) tmpbuf,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) buf,
 					   -1);
 		}
@@ -357,11 +354,27 @@ void main_create_pixbufs(void)
 			pixbuf_finder("book_open_rtol.png", 16, NULL);
 	}
 
-
-	pixbufs->pixbuf_helpdoc =
-	    gtk_widget_render_icon(widgets.app,
-				   GTK_STOCK_DND,
-				   GTK_ICON_SIZE_MENU, NULL);
+#ifdef USE_GTK_3
+	
+#ifdef HAVE_GTK_310  		
+	GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();	
+	pixbufs->pixbuf_helpdoc = 
+		gtk_icon_theme_load_icon (icon_theme,
+                          "gtk-dnd",
+                          GTK_ICON_SIZE_MENU,
+                          GTK_ICON_LOOKUP_FORCE_SIZE,
+                          NULL);
+#else		
+	pixbufs->pixbuf_helpdoc = 
+		gtk_widget_render_icon_pixbuf(widgets.app,
+                                              GTK_STOCK_DND,
+                                              GTK_ICON_SIZE_MENU );
+#endif	
+#else
+	gtk_widget_render_icon(widgets.app,
+			       GTK_STOCK_DND,
+			       GTK_ICON_SIZE_MENU, NULL);
+#endif
 }
 
 
@@ -400,9 +413,9 @@ static void add_verses_to_chapter(GtkTreeModel * model,
 	}
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened, -1);
-	book = backend->key_get_book(work_buf[3]);
-	chapter = backend->key_get_chapter(work_buf[3]);
-	verses = backend->key_verse_count(work_buf[3]);
+	book    = backend->key_get_book(settings.MainWindowModule, work_buf[3]);
+	chapter = backend->key_get_chapter(settings.MainWindowModule, work_buf[3]);
+	verses  = backend->key_verse_count(settings.MainWindowModule, work_buf[3]);
 
 	for (i = 1; i < (verses + 1); i++) {
 		gchar *num = main_format_number(i);
@@ -416,12 +429,12 @@ static void add_verses_to_chapter(GtkTreeModel * model,
 		gtk_tree_store_append(GTK_TREE_STORE(model),
 				      &child_iter, &iter);
 		gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
-				   COL_OPEN_PIXBUF,
-				   pixbufs->pixbuf_helpdoc,
-				   COL_CLOSED_PIXBUF, NULL, COL_CAPTION,
-				   (gchar *) buf, COL_MODULE,
-				   (gchar *) work_buf[2], COL_OFFSET,
-				   (gchar *) key, -1);
+				   COL_OPEN_PIXBUF, pixbufs->pixbuf_helpdoc,
+				   COL_CLOSED_PIXBUF, NULL,
+				   COL_CAPTION, (gchar *) buf,
+				   COL_MODULE, (gchar *) work_buf[2],
+				   COL_OFFSET, (gchar *) key,
+				   -1);
 		g_free(key);
 		g_free(buf);
 	}
@@ -462,8 +475,8 @@ static void add_chapters_to_book(GtkTreeModel * model, GtkTreeIter iter,
 	}
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened, -1);
-	book = backend->key_get_book(work_buf[3]);
-	chapters = backend->key_chapter_count(work_buf[3]);
+	book = backend->key_get_book(settings.MainWindowModule, work_buf[3]);
+	chapters = backend->key_chapter_count(settings.MainWindowModule, work_buf[3]);
 
 	for (i = 1; i < (chapters + 1); i++) {
 		gchar *num = main_format_number(i);
@@ -476,13 +489,12 @@ static void add_chapters_to_book(GtkTreeModel * model, GtkTreeIter iter,
 		gtk_tree_store_append(GTK_TREE_STORE(model),
 				      &child_iter, &iter);
 		gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
-				   COL_OPEN_PIXBUF,
-				   pixbufs->pixbuf_closed,
-				   COL_CLOSED_PIXBUF,
-				   pixbufs->pixbuf_closed, COL_CAPTION,
-				   (gchar *) buf, COL_MODULE,
-				   (gchar *) work_buf[2], COL_OFFSET,
-				   (gchar *) key, -1);
+				   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+				   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+				   COL_CAPTION, (gchar *) buf,
+				   COL_MODULE, (gchar *) work_buf[2],
+				   COL_OFFSET, (gchar *) key,
+				   -1);
 		g_free(key);
 		g_free(buf);
 	}
@@ -510,7 +522,10 @@ static void add_chapters_to_book(GtkTreeModel * model, GtkTreeIter iter,
 static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 			       const gchar * mod_name)
 {
-	VerseKey key;
+	SWModule *mod = backend->get_SWModule(mod_name);
+	if (!mod) return;
+
+	VerseKey *vkey = (VerseKey *)mod->createKey();
 	gint j = 0;
 	GtkTreeIter child_iter;
 	gchar *buf = NULL;
@@ -518,22 +533,19 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter,
 			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened, -1);
 	if (backend->module_has_testament(mod_name, 1)) {
-		while (j < key.BMAX[0]) {
-			key.Testament(1);
-			key.Book(j+1);
-			buf = strdup((gchar *) key.getBookName());
+		while (j < vkey->BMAX[0]) {
+			vkey->setTestament(1);
+			vkey->setBook(j+1);
+			buf = strdup((gchar *) vkey->getBookName());
 			gchar *key = g_strdup_printf("book://%s/%s 1:1",
 						     mod_name, buf);
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter);
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CLOSED_PIXBUF,
-					   pixbufs->pixbuf_closed,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
 					   COL_CAPTION, (gchar *) buf,
-					   COL_MODULE,
-					   (gchar *) mod_name,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) key,
 					   -1);
 			g_free(key);
@@ -543,22 +555,19 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 	}
 	j = 0;
 	if (backend->module_has_testament(mod_name, 2)) {
-		while (j < key.BMAX[1]) {
-			key.Testament(2);
-			key.Book(j+1);
-			buf = strdup((gchar *) key.getBookName());
+		while (j < vkey->BMAX[1]) {
+			vkey->setTestament(2);
+			vkey->setBook(j+1);
+			buf = strdup((gchar *) vkey->getBookName());
 			gchar *key = g_strdup_printf("book://%s/%s 1:1",
 						     mod_name, buf);
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter);
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CLOSED_PIXBUF,
-					   pixbufs->pixbuf_closed,
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
 					   COL_CAPTION, (gchar *) buf,
-					   COL_MODULE,
-					   (gchar *) mod_name,
+					   COL_MODULE, (gchar *) mod_name,
 					   COL_OFFSET, (gchar *) key,
 					   -1);
 			g_free(key);
@@ -566,6 +575,7 @@ static void add_books_to_bible(GtkTreeModel * model, GtkTreeIter iter,
 			++j;
 		}
 	}
+	delete vkey;
 }
 #endif /* ALLOW_BIBLE_NAVIGATION_FROM_SIDEBAR_TREE */
 
@@ -718,12 +728,12 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 		    (GTK_TREE_MODEL(model), &selected)
 		    && strstr(key, "chapter:"))
 			add_verses_to_chapter(model, selected, key);
-#endif
+#endif 
 
-		if (!GTK_CHECK_MENU_ITEM(widgets.viewtexts_item)->active) {
-			GTK_CHECK_MENU_ITEM(widgets.viewtexts_item)->active = 1;
+		if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(widgets.viewtexts_item))) {
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(widgets.viewtexts_item), 1);
 			on_show_bible_text_activate
-			    (GTK_MENU_ITEM(widgets.viewtexts_item), NULL);
+			    (GTK_CHECK_MENU_ITEM(widgets.viewtexts_item), NULL);
 		}
 
 		if (key)
@@ -739,27 +749,27 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					       notebook_comm_book), 0);
 		settings.comm_showing = TRUE;
 
-		if ((!GTK_CHECK_MENU_ITEM(widgets.viewcomms_item)->active) ||
+		if ((!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item))) ||
 		    (!settings.comm_showing)) {
-			GTK_CHECK_MENU_ITEM(widgets.viewcomms_item)->active = 1;
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item), 1);
 			on_show_commentary_activate
-			    (GTK_MENU_ITEM(widgets.viewcomms_item), NULL);
+			    (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item), NULL);
 		}
 		main_display_commentary(mod, settings.currentverse);
 		break;
 
 	case DICTIONARY_TYPE:
-		if (!GTK_CHECK_MENU_ITEM(widgets.viewdicts_item)->active) {
-			GTK_CHECK_MENU_ITEM(widgets.viewdicts_item)->active = 1;
+		if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(widgets.viewdicts_item))) {
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(widgets.viewdicts_item), 1);
 			on_show_dictionary_lexicon_activate
-			    (GTK_MENU_ITEM(widgets.viewcomms_item), NULL);
+			    (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item), NULL);
 		}
 		main_display_dictionary(mod, settings.dictkey);
 		break;
 
 	case BOOK_TYPE:
 	case PRAYERLIST_TYPE:
-		GS_message(("key %s", (key ? key : "-null-")));
+		XI_message(("key %s", (key ? key : "-null-")));
 		settings.comm_showing = FALSE;
 		gtk_notebook_set_current_page(GTK_NOTEBOOK
 					      (widgets.
@@ -780,7 +790,7 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 
 #ifdef USE_TREEVIEW_PATH
 		gchar *path_str = gtk_tree_path_to_string (path);
-		GS_message (("path: %s", path_str));
+		XI_message (("path: %s", path_str));
 		gui_save_treeview_path_string (path_str, mod);
 		g_free (path_str);
 #endif /* USE_TREEVIEW_PATH */
@@ -790,11 +800,11 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					 FALSE);
 		gtk_tree_path_free(path);
 
-		if ((!GTK_CHECK_MENU_ITEM(widgets.viewcomms_item)->active) ||
+		if ((!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item))) ||
 		    (!settings.comm_showing)) {
-			GTK_CHECK_MENU_ITEM(widgets.viewcomms_item)->active = 1;
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item), 1);
 			on_show_commentary_activate
-			    (GTK_MENU_ITEM(widgets.viewcomms_item), NULL);
+			    (GTK_CHECK_MENU_ITEM(widgets.viewcomms_item), NULL);
 		}
 
 		main_display_book(mod, (key ? key : (gchar *) "0"));
@@ -838,11 +848,12 @@ language_add_folders(GtkTreeModel * model,
 		gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
 				   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
 				   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
-				   COL_CAPTION,
-				   ((g_utf8_validate(languages[j], -1, NULL))
-				    ? languages[j]
-				    : _("Unknown")),
-				   COL_MODULE, NULL, COL_OFFSET, NULL, -1);
+				   COL_CAPTION, ((g_utf8_validate(languages[j], -1, NULL))
+						 ? languages[j]
+						 : _("Unknown")),
+				   COL_MODULE, NULL,
+				   COL_OFFSET, NULL,
+				   -1);
 	}
 }
 
@@ -871,16 +882,13 @@ static void add_module_to_prayerlist_folder(GtkTreeModel * model,
 
 	gtk_tree_store_append(GTK_TREE_STORE(model),
 			      &child_iter, &iter);
-	gtk_tree_store_set(GTK_TREE_STORE(model),
-			   &child_iter, COL_OPEN_PIXBUF,
-			   pixbufs->pixbuf_closed,
-			   COL_CLOSED_PIXBUF,
-			   pixbufs->pixbuf_closed,
-			   COL_CAPTION,
-			   (gchar *) module_name,
-			   COL_MODULE,
-			   (gchar *) module_name,
-			   COL_OFFSET, NULL, -1);
+	gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+			   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_CAPTION, (gchar *) module_name,
+			   COL_MODULE, (gchar *) module_name,
+			   COL_OFFSET, NULL,
+			   -1);
 }
 
 
@@ -904,7 +912,8 @@ static void add_module_to_prayerlist_folder(GtkTreeModel * model,
 static void add_module_to_language_folder(GtkTreeModel * model,
 					  GtkTreeIter iter,
 					  const gchar * language,
-					  gchar * module_name)
+					  gchar * module_name,
+					  const gchar * description)
 {
 	GtkTreeIter iter_iter;
 	GtkTreeIter child_iter;
@@ -922,23 +931,24 @@ static void add_module_to_language_folder(GtkTreeModel * model,
 		/* Walk through the list, reading each row */
 		gchar *str_data;
 
-		gtk_tree_model_get(model, &iter_iter, 2, &str_data, -1);
+		gtk_tree_model_get(model, &iter_iter, COL_CAPTION, &str_data, -1);
 		if (!strcmp(language, str_data)) {
+			gchar *content;
 			gtk_tree_store_append(GTK_TREE_STORE(model),
 					      &child_iter, &iter_iter);
-			gtk_tree_store_set(GTK_TREE_STORE(model),
-					   &child_iter, COL_OPEN_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CLOSED_PIXBUF,
-					   pixbufs->pixbuf_closed,
-					   COL_CAPTION,
-					   (gchar *) module_name,
-					   COL_MODULE,
-					   (gchar *) module_name,
+
+			content = g_strdup_printf("%s: %s", module_name, description);
+			gtk_tree_store_set(GTK_TREE_STORE(model), &child_iter,
+					   COL_OPEN_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+					   COL_CAPTION, (gchar *) content,
+					   COL_MODULE, (gchar *) module_name,
 					   COL_OFFSET, NULL, -1);
+			g_free(content);
 			g_free(str_data);
 			return;
 		}
+		g_free(str_data);
 		valid = gtk_tree_model_iter_next(model, &iter_iter);
 	}
 }
@@ -1117,53 +1127,53 @@ void main_load_module_tree(GtkWidget * tree)
 		if (info->is_cult) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      cult, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->type[0] == 'B') {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      text, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->type[0] == 'C') {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      commentary, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->is_maps) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      map, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->is_images) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      image, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->is_devotional) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      devotional, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->is_glossary) {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      glossary, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->type[0] == 'L') {
 			add_module_to_language_folder(GTK_TREE_MODEL(store),
 						      dictionary, info->language,
-						      info->name);
+						      info->name, info->description);
 		}
 		else if (info->type[0] == 'G') {
 			gchar *gstype = main_get_mod_config_entry(info->name, "GSType");
 			if ((gstype == NULL) || strcmp(gstype, "PrayerList")) {
 				add_module_to_language_folder(GTK_TREE_MODEL(store),
 							      book, info->language,
-							      info->name);
+							      info->name, info->description);
 			}
 		}
 		else {
-			GS_warning(("mod `%s' unknown type `%s'",
+			XI_warning(("mod `%s' unknown type `%s'",
 				    info->name, info->type));
 		}
 
@@ -1218,32 +1228,32 @@ void main_add_mod_tree_columns(GtkTreeView * tree)
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_pixbuf_new());
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
 	gtk_tree_view_column_set_attributes
-	    (column, renderer,
-	     "pixbuf", COL_OPEN_PIXBUF,
-	     "pixbuf-expander-open", COL_OPEN_PIXBUF,
-	     "pixbuf-expander-closed", COL_CLOSED_PIXBUF, NULL);
+	    (column, renderer, "pixbuf",
+	     COL_OPEN_PIXBUF, "pixbuf-expander-open",
+	     COL_OPEN_PIXBUF, "pixbuf-expander-closed",
+	     COL_CLOSED_PIXBUF, NULL);
 
 
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer,
-					    "text", COL_CAPTION, NULL);
+	gtk_tree_view_column_set_attributes(column, renderer, "text",
+					    COL_CAPTION, NULL);
 	gtk_tree_view_append_column(tree, column);
 
 
 	column = gtk_tree_view_column_new();
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer,
-					    "text", COL_MODULE, NULL);
+	gtk_tree_view_column_set_attributes(column, renderer, "text",
+					    COL_MODULE, NULL);
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_visible(column, FALSE);
 
 	column = gtk_tree_view_column_new();
 	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer,
-					    "text", COL_OFFSET, NULL);
+	gtk_tree_view_column_set_attributes(column, renderer, "text",
+					    COL_OFFSET, NULL);
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_visible(column, FALSE);
 }
