@@ -89,6 +89,8 @@ using namespace sword;
 char *sword_locale = NULL;
 gboolean companion_activity = FALSE;
 
+extern gboolean valid_scripture_key;
+
 /******************************************************************************
  * Name
  *   main_book_heading
@@ -111,7 +113,7 @@ void main_book_heading(char * mod_name)
 	SWMgr *mgr = backend->get_mgr();
 
 	backend->display_mod = mgr->Modules[mod_name];
-	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
+	vkey = (VerseKey *)(SWKey *)(*backend->display_mod);
 	vkey->setIntros(1);
 	vkey->setAutoNormalize(0);
 	vkey->setChapter(0);
@@ -143,7 +145,7 @@ void main_chapter_heading(char * mod_name)
 
 	backend->display_mod = mgr->Modules[mod_name];
 	backend->display_mod->setKey(settings.currentverse);
-	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);
+	vkey = (VerseKey *)(SWKey *)(*backend->display_mod);
 	vkey->setIntros(1);
 	vkey->setAutoNormalize(0);
 	vkey->setVerse(0);
@@ -184,7 +186,7 @@ void main_save_note(const gchar * module_name,
 		(void) strcpy(rework+1, rework+3);
 	}
 
-	GS_message(("note module %s\nnote key %s\nnote text%s",
+	XI_message(("note module %s\nnote key %s\nnote text%s",
 		    module_name,
 		    key_str,
 		    note_str));
@@ -213,7 +215,7 @@ void main_delete_note(const gchar * module_name,
 		      const gchar * key_str)
 {
 	backend->set_module_key(module_name, key_str);
-	GS_message(("note module %s\nnote key %s\n",
+	XI_message(("note module %s\nnote key %s\n",
 		    module_name,
 		    key_str));
 	backend->delete_entry();
@@ -291,6 +293,28 @@ char *main_getText(char *key)
 }
 
 
+/******************************************************************************
+ * Name
+ *  main_getShortText
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *   void main_getShortText(gchar * key)
+ *
+ * Description
+ *   get short-name key
+ *
+ * Return value
+ *   char *
+ */
+
+char *main_getShortText(char *key)
+{
+	VerseKey vkey(key);
+	return strdup((char *)vkey.getShortText());
+}
+
+
 /******************************************************************************
  * Name
  *   main_update_nav_controls
@@ -307,9 +331,13 @@ char *main_getText(char *key)
  *   gchar *
  */
 
-gchar *main_update_nav_controls(const gchar * key)
+gchar *main_update_nav_controls(const char *module_name, const gchar *key)
 {
-	char *val_key = backend->get_valid_key(key);
+	char *val_key = backend->get_valid_key(module_name, key);
+
+	// we got a valid key. but was it really a valid key within v11n?
+	// for future use in determining whether to show normal navbar content.
+	navbar_versekey.valid_key = main_is_Bible_key(module_name, key);
 
 	/*
 	 *  remember verse
@@ -554,7 +582,7 @@ void main_init_language_map() {
 		    (_("Xiphos's file for language\nabbreviations is missing."));
 		return;
 	}
-	GS_message(("%s",language_file));
+	XI_message(("%s",language_file));
 
 	if ((language = fopen(language_file, "r")) == NULL) {
 		gui_generic_warning
@@ -586,7 +614,7 @@ void main_init_language_map() {
 
 	for (s = mapspace; s < end; ++s) {
 		if ((newline = strchr(s, '\n')) == NULL) {
-			GS_message(("incomplete last line in languages"));
+			XI_message(("incomplete last line in languages"));
 			break;
 		}
 		*newline = '\0';
@@ -598,7 +626,7 @@ void main_init_language_map() {
 
 		abbrev = s;
 		if ((name = strchr(s, '\t')) == NULL) {
-			GS_message(("tab-less line in languages"));
+			XI_message(("tab-less line in languages"));
 			break;
 		}
 		*(name++) = '\0';	// NUL-terminate abbrev, mark name.
@@ -701,13 +729,13 @@ void main_init_backend(void)
 //#ifndef DEBUG
 	g_chdir(settings.path_to_mods);
 //#else
-//	GS_warning(("no chdir(SWORD_PATH) => modmgr 'archive' may not work"));
+//	XI_warning(("no chdir(SWORD_PATH) => modmgr 'archive' may not work"));
 //#endif
-	GS_print(("%s sword-%s\n", "Starting", backend->get_sword_version()));
-	GS_print(("%s\n", "Initiating SWORD"));
-	GS_print(("%s: %s\n","path to sword", settings.path_to_mods));
-	GS_print(("%s %s\n", "SWORD locale is", lang));
-	GS_print(("%s\n", "Checking for SWORD Modules"));
+	XI_print(("%s sword-%s\n", "Starting", backend->get_sword_version()));
+	XI_print(("%s\n", "Initiating SWORD"));
+	XI_print(("%s: %s\n","path to sword", settings.path_to_mods));
+	XI_print(("%s %s\n", "SWORD locale is", lang));
+	XI_print(("%s\n", "Checking for SWORD Modules"));
 	settings.spell_language = strdup(lang);
 	main_init_lists();
 
@@ -750,7 +778,7 @@ void main_shutdown_backend(void)
 	        delete backend;
 	backend = NULL;
 
-	GS_print(("%s\n", "SWORD is shutdown"));
+	XI_print(("%s\n", "SWORD is shutdown"));
 }
 
 /******************************************************************************
@@ -842,7 +870,7 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	}
 	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
 
-	GS_message(("\nold_key: %s\nkey: %s",old_key,key));
+	XI_message(("\nold_key: %s\nkey: %s",old_key,key));
 	backend->set_module_key(mod_name, key);
 	g_free(key);
 	key = backend->get_module_key();
@@ -929,7 +957,7 @@ void main_display_book(const char * mod_name,
 	if (key == NULL)
 		key = "0";
 
-	GS_message(("main_display_book\nmod_name: %s\nkey: %s", mod_name, key));
+	XI_message(("main_display_book\nmod_name: %s\nkey: %s", mod_name, key));
 
 	if (!backend->is_module(mod_name))
 		return;
@@ -991,6 +1019,11 @@ void main_display_commentary(const char * mod_name,
 
 	if (!mod_name || !backend->is_module(mod_name))
 		return;
+
+	int modtype = backend->module_type(mod_name);
+	if ((modtype != COMMENTARY_TYPE) && (modtype != PERCOM_TYPE))
+		return;		// what are we doing here?
+	
 	if (!settings.CommWindowModule)
 		settings.CommWindowModule = g_strdup((gchar*)mod_name);
 
@@ -1039,9 +1072,13 @@ void main_display_commentary(const char * mod_name,
 
 	main_check_unlock(mod_name, TRUE);
 
+	valid_scripture_key = main_is_Bible_key(mod_name, key);
+
 	backend->set_module_key(mod_name, key);
 	backend->display_mod->display();
 
+	valid_scripture_key = TRUE;	// leave nice for future use.
+
 	//if (settings.browsing)
 		gui_update_tab_struct(NULL,
 				      mod_name,
@@ -1067,7 +1104,7 @@ void main_display_dictionary(const char * mod_name,
 	if (!settings.havedict || !mod_name)
 		return;
 
-	GS_message(("main_display_dictionary\nmod_name: %s\nkey: %s", mod_name, key));
+	XI_message(("main_display_dictionary\nmod_name: %s\nkey: %s", mod_name, key));
 
 	if (!backend->is_module(mod_name))
 		return;
@@ -1130,8 +1167,6 @@ void main_display_dictionary(const char * mod_name,
 void main_display_bible(const char * mod_name,
 			const char * key)
 {
-	gchar *file = NULL;
-	gchar *style = NULL;
 	gchar *val_key = NULL;
 
 	/* keeps us out of a crash causing loop */
@@ -1152,6 +1187,10 @@ void main_display_bible(const char * mod_name,
 	if (!backend->is_module(mod_name))
 		return;
 
+	int modtype = backend->module_type(mod_name);
+	if (modtype != TEXT_TYPE)
+		return;		// what are we doing here?
+	
 	if (!settings.MainWindowModule)
 		settings.MainWindowModule = g_strdup((gchar*)mod_name);
 
@@ -1212,33 +1251,28 @@ void main_display_bible(const char * mod_name,
 
 	settings.whichwindow = MAIN_TEXT_WINDOW;
 
-	file = g_strdup_printf("%s/modops.conf", settings.gSwordDir);
-	style = get_conf_file_item(file, mod_name, "style");
-	if ((style) && !strcmp(style,"verse"))
-		settings.versestyle = TRUE;
-	else
-		settings.versestyle = FALSE;
-	g_free(style);
-	g_free(file);
-
 	main_check_unlock(mod_name, TRUE);
 
+	valid_scripture_key = main_is_Bible_key(mod_name, key);
+
 	if (backend->module_has_testament(mod_name,
-				backend->get_key_testament(key))) {
-			backend->set_module_key(mod_name, key);
-			backend->display_mod->display();
+				backend->get_key_testament(mod_name, key))) {
+		backend->set_module_key(mod_name, key);
+		backend->display_mod->display();
 	} else {
-		if (backend->get_key_testament(key) == 1)
-			val_key = main_update_nav_controls("Matthew 1:1");
+		if (backend->get_key_testament(mod_name, key) == 1)
+			val_key = main_update_nav_controls(mod_name, "Matthew 1:1");
 		else
-			val_key = main_update_nav_controls("Genesis 1:1");
+			val_key = main_update_nav_controls(mod_name, "Genesis 1:1");
 
 		backend->set_module_key(mod_name, val_key);
 		backend->display_mod->display();
 		g_free(val_key);
 	}
 
-	GS_message(("mod_name = %s",mod_name));
+	valid_scripture_key = TRUE;	// leave nice for future use.
+
+	XI_message(("mod_name = %s",mod_name));
 	//if (settings.browsing) {
 		gui_update_tab_struct(mod_name,
 				      NULL,
@@ -1359,6 +1393,27 @@ const char *main_get_module_language(const char *module_name)
 
 
 
+/******************************************************************************
+ * Name
+ *  main_check_for_option
+ *
+ * Synopsis
+ *   #include ".h"
+ *
+ *  	gint main_check_for_option(const gchar * mod_name, const gchar * key, const gchar * option)
+ *
+ * Description
+ *    get any option for a module
+ *
+ * Return value
+ *   gint
+ */
+
+gint main_check_for_option(const gchar * mod_name, const gchar * key, const gchar * option)
+{
+	return backend->has_option(mod_name, key, option);
+}
+
 /******************************************************************************
  * Name
  *  main_check_for_global_option
@@ -1366,7 +1421,7 @@ const char *main_get_module_language(const char *module_name)
  * Synopsis
  *   #include ".h"
  *
- *  	gint main_check_for_global_option(gchar * mod_name, gchar * option)
+ *  	gint main_check_for_global_option(const gchar * mod_name, const gchar * option)
  *
  * Description
  *    get global options for a module
@@ -1375,7 +1430,7 @@ const char *main_get_module_language(const char *module_name)
  *   gint
  */
 
-gint main_check_for_global_option(gchar * mod_name, gchar * option)
+gint main_check_for_global_option(const gchar * mod_name, const gchar * option)
 {
 	return backend->has_global_option(mod_name, option);
 }
@@ -1871,9 +1926,9 @@ void main_flush_widgets_content(void)
  * Return value
  *   gboolean
  */
-gboolean main_is_Bible_key(gchar *key)
+gboolean main_is_Bible_key(const gchar *name, const gchar *key)
 {
-	return (gboolean)(backend->is_Bible_key(key, settings.currentverse) != 0);
+    return (gboolean)(backend->is_Bible_key(name, key, settings.currentverse) != 0);
 }
 
 /******************************************************************************
