@@ -36,6 +36,7 @@
 
 #include "main/tab_history.h"
 #include "main/settings.h"
+#include "main/sidebar.h"
 #include "main/sword.h"
 #include "main/url.hh"
 #include "main/xml.h"
@@ -184,6 +185,46 @@ void main_add_tab_history_item(gpointer data)
 	tab->first_back_click = TRUE;
 }
 
+/******************************************************************************
+ * Name
+ *   main_fake_tab_history_item
+ *
+ * Synopsis
+ *   #include "main/tab_history.h"
+ *
+ *   void main_fake_tab_history_item(char *reference)
+ *
+ * Description
+ *    fake an unreal history item into the history menu
+ *
+ * Return value
+ *   void
+ */
+void main_fake_tab_history_item(char *reference)
+{
+    PASSAGE_TAB_INFO *tab = cur_passage_tab;
+    int i;
+
+    /* if we have hit max length, dispose of oldest */
+    if (tab->history_items == TABHISTORYLENGTH) {
+	for (i = 0; i < (TABHISTORYLENGTH - 1); ++i) {
+	    tab->history_list[i] = tab->history_list[i + 1];
+	}
+	--tab->history_items;
+    }
+
+    /* add item to history menu */
+    strcpy(tab->history_list[tab->history_items].verseref, reference);
+    if (tab->text_mod)
+	strcpy(tab->history_list[tab->history_items].textmod, tab->text_mod);
+    if (tab->commentary_mod)
+	strcpy(tab->history_list[tab->history_items].commod, tab->commentary_mod);
+
+    ++tab->history_items;
+    /* do not update what's current in history list. */
+    main_update_tab_history_menu(tab);
+}
+
 /******************************************************************************
  * Name
  *  on_clear_activate
@@ -192,7 +233,7 @@ void main_add_tab_history_item(gpointer data)
  *   #include ".h"
  *
  *   void on_clear_activate(GtkMenuItem * menuitem,
- *						gpointer user_data)
+ *			    gpointer user_data)
  *
  * Description
  *   remove all items from history list by calling
@@ -207,6 +248,43 @@ void on_clear_activate(GtkMenuItem * menuitem, gpointer user_data)
 	main_clear_tab_history();
 }
 
+/******************************************************************************
+ * Name
+ *  on_history_to_verse_list_activate
+ *
+ * Synopsis
+ *   #include ".h"
+ *
+ *   void on_history_to_verse_list_activate(GtkMenuItem * menuitem,
+ *					    gpointer user_data)
+ *
+ * Description
+ *   ship the history content to the verse list.
+ *
+ * Return value
+ *   void
+ */
+
+void on_history_to_verse_list_activate(GtkMenuItem * menuitem, gpointer user_data)
+{
+    int i;
+    gboolean first = TRUE;
+    GString *list = g_string_new("");
+
+    for (i = 0; i < cur_passage_tab->history_items; ++i) {
+	if (!first)
+	    g_string_append_c(list, ';');
+	g_string_append(list, cur_passage_tab->history_list[i].verseref);
+	first = FALSE;
+    }
+
+    main_display_verse_list_in_sidebar
+	(settings.currentverse, settings.MainWindowModule, list->str);
+
+    g_string_free(list, TRUE);
+    return;
+}
+
 GtkWidget *main_versekey_drop_down_new(gpointer data)
 {
 	gint i;
@@ -216,13 +294,18 @@ GtkWidget *main_versekey_drop_down_new(gpointer data)
 
 	tab = (PASSAGE_TAB_INFO*) data;
 	menu = gtk_menu_new();
+
 	item = gtk_menu_item_new_with_label(_("Clear History"));
 	gtk_widget_show(item);
-		g_signal_connect(G_OBJECT(item), "activate",
-				   G_CALLBACK
-				   (on_clear_activate),
-				   NULL);
-		gtk_container_add(GTK_CONTAINER(menu), item);
+	g_signal_connect(G_OBJECT(item), "activate",
+			 G_CALLBACK(on_clear_activate), NULL);
+	gtk_container_add(GTK_CONTAINER(menu), item);
+
+	item = gtk_menu_item_new_with_label(_("History ➛ Verse List"));
+	gtk_widget_show(item);
+	g_signal_connect(G_OBJECT(item), "activate",
+			 G_CALLBACK(on_history_to_verse_list_activate), NULL);
+	gtk_container_add(GTK_CONTAINER(menu), item);
 
 	for (i = 0; i < tab->history_items; ++i) {
 		item = gtk_menu_item_new_with_label(tab->history_list[i].verseref);
@@ -263,10 +346,11 @@ void main_change_verse_tab_history(gint historynum)
 	tab->current_history_item = historynum;
 	settings.addhistoryitem = tab->first_back_click;
 
-	GS_print(("commod = %s\n",tab->history_list[historynum].commod));
-	GS_print(("textmod = %s\n",tab->history_list[historynum].textmod));
+	XI_print(("commod = %s\n",tab->history_list[historynum].commod));
+	XI_print(("textmod = %s\n",tab->history_list[historynum].textmod));
 
-	key = main_update_nav_controls(tab->history_list[historynum].verseref);
+	key = main_update_nav_controls(tab->history_list[historynum].textmod,
+				       tab->history_list[historynum].verseref);
 	main_display_commentary(tab->history_list[historynum].commod, key);
 	main_display_bible(tab->history_list[historynum].textmod, key);
 	main_keep_bibletext_dialog_in_sync(key);
